@@ -45,15 +45,13 @@ OC.L10N.register(
     "Add mail account" : "Voeg posrekening toe",
     "Newest first" : "Nuutste eerste",
     "Oldest first" : "Oudste eerste",
-    "Register" : "Registreer",
     "Security" : "Sekuriteit",
-    "Keyboard shortcuts" : "Sneltoetse",
+    "About" : "Aangaande",
     "Archive" : "Argief",
     "Delete" : "Skrap",
     "Search" : "Soek",
     "Send" : "Stuur",
     "Refresh" : "Verfris",
-    "About" : "Aangaande",
     "No certificate" : "Geen sertifikaat",
     "Certificate updated" : "Sertifikaat bygewerk",
     "Could not update certificate" : "Kon nie sertifikaat bywerk nie",
@@ -84,8 +82,8 @@ OC.L10N.register(
     "Comment" : "Kommentaar",
     "Accept" : "Aanvaar",
     "Remove" : "Verwyder",
-    "email" : "e-pos",
     "Choose target folder" : "Kies teikenvouer",
+    "Favorites" : "Gunstelinge",
     "Other" : "Ander",
     "Forward" : "Stuur aan",
     "View source" : "Bekyk bron",
@@ -105,6 +103,7 @@ OC.L10N.register(
     "Tags" : "Etikette",
     "Custom" : "Eie",
     "Message source" : "Boodskapbron",
+    "Deleted" : "Geskrap",
     "Recipient" : "Ontvanger",
     "Help" : "Hulp",
     "Actions" : "Aksies",
@@ -122,7 +121,6 @@ OC.L10N.register(
     "Connect your mail account" : "Koppel u posrekening",
     "All" : "Alle",
     "Drafts" : "Konsepte",
-    "Favorites" : "Gunstelinge",
     "All inboxes" : "Alle inkassies",
     "Inbox" : "Inkassie",
     "Junk" : "Gemorspos",
@@ -132,10 +130,6 @@ OC.L10N.register(
     "Forwarding to %s" : "Stuur aan na %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
     "Redirect" : "Herverwys",
-    "The link leads to %s" : "Die skakel lei na %s",
-    "Accounts" : "Accounts",
-    "Contact or email address …" : "Kontak of e-posadres …",
-    "Write message …" : "Skryf boodskap…",
-    "Loading …" : "Laai …"
+    "The link leads to %s" : "Die skakel lei na %s"
 },
 "nplurals=2; plural=(n != 1);");
