@@ -40,24 +40,22 @@ OC.L10N.register(
     "Cancel" : "Encaboxar",
     "General" : "Xeneral",
     "Appearance" : "Aspeutu",
-    "List" : "Llista",
     "Vertical split" : "DIxebra verical",
     "Horizontal split" : "Dixebra horizontal",
+    "List" : "Llista",
     "Sorting" : "Orde",
     "Newest first" : "Primero lo nuevo",
     "Oldest first" : "Primero lo antiguo",
-    "Gravatar settings" : "Configuración de Gravatar",
-    "Register" : "Rexistrase",
     "Shared with me" : "Compartióse conmigo",
+    "Privacy" : "Privacidá",
     "Security" : "Seguranza",
     "S/MIME" : "S/MIME",
-    "Keyboard shortcuts" : "Atayos del tecláu",
+    "About" : "Tocante a",
     "Archive" : "Archivar",
     "Delete" : "Desaniciar",
     "Search" : "Buscar",
     "Send" : "Unviar",
     "Refresh" : "Anovar",
-    "About" : "Tocante a",
     "Ok" : "D'acuerdu",
     "Certificate updated" : "Anovóse'l certificáu",
     "Could not update certificate" : "Nun se pudo anovar el certificáu",
@@ -146,6 +144,7 @@ OC.L10N.register(
     "Last month" : "El mes anterior",
     "Choose target folder" : "Escoyer la carpeta de destín",
     "No more submailboxes in here" : "Equí nun hai más sobandexes",
+    "Favorites" : "Favoritos",
     "Important info" : "Información importante",
     "Forward" : "Avanzar",
     "Move message" : "Mover el mensaxe",
@@ -175,6 +174,7 @@ OC.L10N.register(
     "Delete folder" : "Desaniciar la carpeta",
     "An error occurred, unable to rename the mailbox." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
     "Rename" : "Renomar",
+    "Delete all messages" : "Desaniciar tolos mensaxes",
     "Outbox" : "Bandexa de salida",
     "New message" : "Mensaxe nuevu",
     "Edit message" : "Editar el mensaxe",
@@ -212,7 +212,6 @@ OC.L10N.register(
     "Pick an end date" : "Escoyer una data de fin",
     "Tags" : "Etiquetes",
     "Select tags" : "Seleicionar etiquetes",
-    "Last 7 days" : "Los últimos 7 díes",
     "Sieve Port" : "Puertu de sieve",
     "Custom" : "Personalizar",
     "Sieve User" : "Usuariu de sieve",
@@ -245,6 +244,7 @@ OC.L10N.register(
     "Untitled event" : "Eventu ensin títulu",
     "Airplane" : "Avión",
     "Train" : "Tren",
+    "Deleted" : "Desanicióse",
     "Help" : "Ayuda",
     "contains" : "contién",
     "matches" : "concasa",
@@ -291,7 +291,6 @@ OC.L10N.register(
     "You can close this window" : "Pues zarrar esta ventana",
     "All" : "Too",
     "Drafts" : "Borradores",
-    "Favorites" : "Favoritos",
     "All inboxes" : "Toles bandexes",
     "Inbox" : "Bandexa",
     "Junk" : "Puxarra",
@@ -311,9 +310,6 @@ OC.L10N.register(
     "Error loading message" : "Hebo un error al cargar el mensaxe",
     "Redirect" : "Redirixir",
     "The link leads to %s" : "L'enllaz lleva a %s",
-    "Accounts" : "Cuentes",
-    "Loading messages …" : "Cargando los mensaxes…",
-    "Loading …" : "Cargando…",
-    "Saving tag …" : "Guardando la etiqueta…"
+    "Last 7 days" : "Los últimos 7 díes"
 },
 "nplurals=2; plural=(n != 1);");
