@@ -47,7 +47,7 @@ OC.L10N.register(
     "Sorting" : "Сартаванне",
     "Newest first" : "Спачатку новыя",
     "Oldest first" : "Спачатку старыя",
-    "Privacy and security" : "Прыватнасць і бяспека",
+    "Privacy" : "Прыватнасць",
     "Security" : "Бяспека",
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Кіраванне сертыфікатамі",
@@ -55,13 +55,12 @@ OC.L10N.register(
     "Install the browser extension" : "Усталюйце пашырэнне для браўзера",
     "Step 2" : "Крок 2",
     "Enable for the current domain" : "Уключыце для бягучага дамена",
-    "Keyboard shortcuts" : "Спалучэнні клавіш",
+    "About" : "Аб праграме",
     "Archive" : "Архіў",
     "Delete" : "Выдаліць",
     "Search" : "Пошук",
     "Send" : "Адправіць",
     "Refresh" : "Абнавіць",
-    "About" : "Аб праграме",
     "Ok" : "ОК",
     "From" : "Ад",
     "Select account" : "Выберыце ўліковы запіс",
@@ -127,6 +126,7 @@ OC.L10N.register(
     "Last month" : "Мінулы месяц",
     "Loading messages …" : "Загрузка паведамленняў …",
     "Choose target folder" : "Выберыце мэтавую папку",
+    "Favorites" : "Абранае",
     "Other" : "Іншае",
     "Forward" : "Пераслаць",
     "Move message" : "Перамясціць паведамленне",
@@ -154,6 +154,7 @@ OC.L10N.register(
     "Rename" : "Перайменаваць",
     "Move folder" : "Перамясціць папку",
     "Clear cache" : "Ачысціць кэш",
+    "Delete all messages" : "Выдаліць усе паведамленні",
     "Translate this message to {language}" : "Перакласці гэта паведамленне на {language}",
     "New message" : "Новае паведамленне",
     "Edit message" : "Рэдагаваць паведамленне",
@@ -178,7 +179,6 @@ OC.L10N.register(
     "Pick a start date" : "Выберыце дату пачатку",
     "Pick an end date" : "Выберыце дату заканчэння",
     "Tags" : "Тэгі",
-    "Last 7 days" : "Апошнія 7 дзён",
     "Custom" : "Карыстальніцкі",
     "Signature …" : "Подпіс …",
     "Saving new tag name …" : "Захаванне новай назвы тэга …",
@@ -204,8 +204,12 @@ OC.L10N.register(
     "Untitled event" : "Падзея без назвы",
     "(organizer)" : "(арганізатар)",
     "Train" : "Цягнік",
+    "Mark message as" : "Пазначыць паведамленне як",
     "Move into folder" : "Перамясціць у папку",
     "Stop" : "Спыніць",
+    "Answered" : "Адказанае",
+    "Deleted" : "Выдаленае",
+    "Seen" : "Прачытанае",
     "Delete filter" : "Выдаліць фільтр",
     "New filter" : "Новы фільтр",
     "Filter is active" : "Фільтр актыўны",
@@ -247,7 +251,6 @@ OC.L10N.register(
     "Insert" : "Уставіць",
     "All" : "Усе",
     "Drafts" : "Чарнавікі",
-    "Favorites" : "Абранае",
     "Priority inbox" : "Прыярытэтныя",
     "Inbox" : "Уваходныя",
     "Sent" : "Адпраўленыя",
@@ -266,10 +269,6 @@ OC.L10N.register(
     "Could not load the message" : "Не ўдалося загрузіць паведамленне",
     "Error loading message" : "Памылка пры загрузцы паведамлення",
     "Forwarding to %s" : "Перасыланне да %s",
-    "Accounts" : "Уліковыя запісы",
-    "Subject …" : "Тэма …",
-    "Write message …" : "Напішыце паведамленне …",
-    "Saving draft …" : "Захаванне чарнавіка …",
-    "Loading …" : "Загрузка …"
+    "Last 7 days" : "Апошнія 7 дзён"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
