@@ -36,10 +36,9 @@ OC.L10N.register(
     "List" : "Rhestr",
     "Newest first" : "Diweddaraf gyntaf",
     "Oldest first" : "Hynaf gyntaf",
-    "Register" : "Cofrestru",
     "Security" : "Diogelwch",
     "Manage certificates" : "Rheoli tystysgrifau",
-    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
+    "About" : "Ynglyn â",
     "Compose new message" : "Ysgrifennu Neges _Newydd",
     "Newer message" : "Neges diweddarach",
     "Older message" : "Neges hyn",
@@ -50,7 +49,6 @@ OC.L10N.register(
     "Search" : "Chwilio",
     "Send" : "Anfon",
     "Refresh" : "Ail-lwytho",
-    "About" : "Ynglyn â",
     "Ok" : "Iawn",
     "Subject" : "Pwnc",
     "Draft saved" : "Cadwyd y drafft",
@@ -74,6 +72,7 @@ OC.L10N.register(
     "Decline" : "Gwrthod",
     "Remove" : "Gwaredu",
     "Today" : "Heddiw",
+    "Favorites" : "Ffefrynnau",
     "Other" : "Arall",
     "Translate" : "Cyfieithu",
     "Choose a folder to store the attachment in" : "Dewiswch ffolder i gadw'r atodiad ynddi",
@@ -89,7 +88,6 @@ OC.L10N.register(
     "Show all folders" : "Dangos pob ffolder",
     "Collapse folders" : "Cwympo ffolderi",
     "Mark all as read" : "Marcio'r cyfan wedi'u darllen",
-    "Mark all messages of this folder as read" : "Marcio'r holl negeseuon y ffolder hon fel y'u darllenwyd",
     "Add subfolder" : "Ychwanegu is-ffolder",
     "Rename" : "Ailenwi",
     "New message" : "Neges newydd",
@@ -103,6 +101,7 @@ OC.L10N.register(
     "Not found" : "Heb ei ganfod",
     "Untitled event" : "Digwyddiad di-deitl",
     "(organizer)" : "(trefnydd)",
+    "Deleted" : "Wedi dileu",
     "Recipient" : "Derbynnydd",
     "Help" : "Cymorth",
     "Actions" : "Gweithredoedd",
@@ -115,7 +114,6 @@ OC.L10N.register(
     "Connect your mail account" : "Cysylltu â'r cyfrif e-bost",
     "All" : "Popeth",
     "Drafts" : "Drafftiau",
-    "Favorites" : "Ffefrynnau",
     "All inboxes" : "Pob blwch derbyn",
     "Inbox" : "Blwch Derbyn",
     "Junk" : "Sothach",
@@ -135,9 +133,6 @@ OC.L10N.register(
     "Redirect" : "Ailgyfeirio",
     "The link leads to %s" : "Mae'r ddolen yn arwain at %s",
     "Continue to %s" : "Parhau i %s",
-    "Accounts" : "Accounts",
-    "Use Gravatar and favicon avatars" : "Defnyddiwch Gravatar ac afatarau favicon",
-    "Saving draft …" : "Yn cadw drafft …",
-    "Loading …" : "Yn llwytho …"
+    "Mark all messages of this folder as read" : "Marcio'r holl negeseuon y ffolder hon fel y'u darllenwyd"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
