@@ -108,35 +108,29 @@ OC.L10N.register(
     "Email address" : "Email adresse",
     "Add alias" : "Tilføj alias",
     "Create alias" : "Opret alias",
-    "Cancel" : "Annuller",
+    "Cancel" : "Annullér",
     "Activate" : "Aktivér",
     "Remind about messages that require a reply but received none" : "Mind mig om beskeder som kræver et svar, men ikke har modtaget et",
     "Could not update preference" : "Præference kunne ikke opdateres",
     "Mail settings" : "Mail indstillinger",
     "General" : "Generelt",
     "Add mail account" : "Tilføj mail konto",
-    "Settings for:" : "Indstillinger for:",
     "Appearance" : "Udseende",
+    "Show all messages in thread" : "Vis alle beskeder i tråde",
     "Layout" : "Layout",
-    "List" : "Liste",
     "Vertical split" : "Vertikal opdeling",
     "Horizontal split" : "Horisontal opdeling",
+    "List" : "Liste",
     "Sorting" : "Sortering",
     "Newest first" : "Nyeste først",
     "Oldest first" : "Ældste først",
-    "Show all messages in thread" : "Vis alle beskeder i tråde",
     "Top" : "Top",
     "Bottom" : "Bund",
-    "Search in body" : "Søg i body",
-    "Gravatar settings" : "Gravatar indstillinger",
-    "Mailto" : "Mail til",
-    "Register" : "Register",
     "Text blocks" : "Tekstblokke",
     "New text block" : "Ny tekstblok",
     "Shared with me" : "Delt med mig",
-    "Privacy and security" : "Privatliv og sikkerhed",
+    "Privacy" : "Privatliv",
     "Security" : "Sikkerhed",
-    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Fremhæv eksterne e-mailadresser ved at aktivere denne funktion. Håndter dine interne adresser og domæner, for at sikre at genkendte kontakter forbliver ikke markerede.",
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Håndter certifikater",
     "Mailvelope" : "Mailvelope",
@@ -145,7 +139,7 @@ OC.L10N.register(
     "Install the browser extension" : "Installér browserudvidelsen",
     "Step 2" : "Trin 2",
     "Enable for the current domain" : "Aktivér for det aktuelle domæne",
-    "Keyboard shortcuts" : "Tastaturgenveje",
+    "About" : "Om",
     "Compose new message" : "Skriv en ny meddelelse",
     "Newer message" : "Nyere besked",
     "Older message" : "Ældre besked",
@@ -156,8 +150,6 @@ OC.L10N.register(
     "Search" : "Søg",
     "Send" : "Send",
     "Refresh" : "Opdatér",
-    "About" : "Om",
-    "Mail version: {version}" : "Mail version: {version}",
     "Title of the text block" : "Titel på ny tekstblok",
     "Content of the text block" : "Indhold i tekstblok",
     "Ok" : "OK",
@@ -332,7 +324,6 @@ OC.L10N.register(
     "individual" : "individuel",
     "domain" : "domæne",
     "Remove" : "Fjern",
-    "email" : "e-mail",
     "Add internal address" : "Tilføj intern adresse",
     "Add internal email or domain" : "Tilføj interne e-mail eller domæne",
     "Could not mark message as seen/unseen" : "Kunne ikke markere besked som set/ikke set",
@@ -347,6 +338,7 @@ OC.L10N.register(
     "Choose target folder" : "Vælg destinationsmappe",
     "No more submailboxes in here" : "Ikke flere underpostkasser herinde",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Beskeder vil automatisk blive markeret som vigtige baseret på, hvilke meddelelser du har interageret med eller markeret som vigtige. I begyndelsen skal du muligvis manuelt ændre vigtigheden for at lære systemet, men det vil forbedres med tiden.",
+    "Favorites" : "Favoritter",
     "Follow up" : "Opfølgning",
     "Follow up info" : "Opfølgningsinfo",
     "Load more follow ups" : "Indlæs flere opfølgninger",
@@ -419,7 +411,6 @@ OC.L10N.register(
     "An error occurred, unable to rename the mailbox." : "En fejl er opstået, kunne ikke omdøbe mailboksen.",
     "Please wait 10 minutes before repairing again" : "Vent venligst 10 minutter inden du reparerer igen",
     "Mark all as read" : "Markér alle som læst",
-    "Mark all messages of this folder as read" : "Markér alle beskeder i denne mappe som læst",
     "Add subfolder" : "Tilføj undermappe",
     "Rename" : "Omdøb",
     "Move folder" : "Flyt mappe",
@@ -428,6 +419,7 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Ryd lokalt cachet data, hvis der er problemer med synkronisering.",
     "Subscribed" : "Abonneret",
     "Sync in background" : "Synkroniser i baggrunden",
+    "Delete all messages" : "Slet alle beskeder",
     "Outbox" : "Udbakke",
     "Translate this message to {language}" : "Oversæt denne besked til {language}",
     "New message" : "Ny besked",
@@ -491,8 +483,6 @@ OC.L10N.register(
     "Has attachments" : "Har vedhæftede filer",
     "Mentions me" : "Omtalte mig",
     "Has attachment" : "Har vedhæftning",
-    "Last 7 days" : "Sidste 7 dage",
-    "From me" : "Fra mig",
     "Enable mail body search" : "Aktivér søgning i mailhovedtekst",
     "Sieve credentials" : "Sieve legitimationsoplysninger",
     "IMAP credentials" : "IMAP legitimationsoplysninger",
@@ -525,6 +515,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} fra {depStation} til {arrStation}",
     "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}",
     "Train" : "Tog",
+    "Deleted" : "Slettet",
     "Recipient" : "Modtager",
     "New filter" : "Nyt filter",
     "Help" : "Hjælp",
@@ -571,7 +562,6 @@ OC.L10N.register(
     "Connect your mail account" : "Forbind din mail konto",
     "All" : "Alle",
     "Drafts" : "Udkast",
-    "Favorites" : "Favoritter",
     "Priority inbox" : "Prioriteret indbakke",
     "All inboxes" : "Alle indbakker",
     "Inbox" : "Indbakke",
@@ -595,32 +585,8 @@ OC.L10N.register(
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
     "Continue to %s" : "Videre til %s",
-    "Search in the body of messages in priority Inbox" : "Søg i hovedteksten i beskeder i prioritets indbakke ",
-    "Put my text to the bottom of a reply instead of on top of it." : "Sæt min tekst til bunden af et svar i stedet for oven på den.",
-    "Use internal addresses" : "Anvend interne adresser",
-    "Accounts" : "Konti",
-    "Newest" : "Nyeste",
-    "Oldest" : "Ældste",
-    "Reply text position" : "Svartekst placering",
-    "Use Gravatar and favicon avatars" : "Brug Gravatar og favicon avatarer",
-    "Register as application for mail links" : "Registrer som program til at åbne mail links",
-    "Create a new text block" : "Opret en ny tekstblok",
-    "Data collection consent" : "Dataindsamlingssamtykke",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillad, at appen indsamler data om dine interaktioner. Baseret på disse data vil appen tilpasse sig dine præferencer. Dataene gemmes kun lokalt.",
-    "Trusted senders" : "Betroede afsendere",
-    "Internal addresses" : "Interne adresser",
-    "Manage S/MIME certificates" : "Administrer S/MIME-certifikater",
-    "Mailvelope is a browser extension that enables easy OpenPGP encryption and decryption for emails." : "Mailvelope er en browser udvidelse som giver mulighed for let OpenPGP kryptering og dekryptering til e-mails.",
-    "Step 1: Install Mailvelope browser extension" : "Trin 1: Installer Mailvelope browser udvidelse",
-    "Step 2: Enable Mailvelope for the current domain" : "Trin 2: Aktiver Mailvelope for det aktuelle domæne",
-    "Contact or email address …" : "Kontakt eller email…",
-    "Subject …" : "Emne…",
-    "Write message …" : "Skriv en besked…",
-    "Saving draft …" : "Gemmer kladde…",
-    "Loading messages …" : "Indlæser beskeder...",
-    "Loading …" : "Indlæser…",
-    "Contact name …" : "Kontaktnavn ...",
-    "Signature …" : "Underskrift …",
-    "Saving new tag name …" : "Gemmer nyt tag navn ..."
+    "Mark all messages of this folder as read" : "Markér alle beskeder i denne mappe som læst",
+    "Last 7 days" : "Sidste 7 dage",
+    "From me" : "Fra mig"
 },
 "nplurals=2; plural=(n != 1);");
