@@ -46,9 +46,7 @@ OC.L10N.register(
     "Add mail account" : "Aldoni retpoŝtan konton",
     "Newest first" : "Pli novaj unue",
     "Oldest first" : "Malpli novaj unue",
-    "Register" : "Registriĝi",
     "Security" : "Sekurigo",
-    "Keyboard shortcuts" : "Fulmoklavoj",
     "Compose new message" : "Krei novan mesaĝon",
     "Newer message" : "Pli nova mesaĝo",
     "Older message" : "Pli malnova mesaĝo",
@@ -93,9 +91,9 @@ OC.L10N.register(
     "Accept" : "Akcepti",
     "Decline" : "Malakcepti",
     "Remove" : "Forigi",
-    "email" : "retpoŝtadreso",
     "Today" : "Hodiaŭ",
     "Choose target folder" : "Elekti celan dosierujon",
+    "Favorites" : "Pliŝataĵoj",
     "Other" : "Alia",
     "Forward" : "Antaŭen",
     "Translate" : "Traduku",
@@ -118,7 +116,6 @@ OC.L10N.register(
     "Collapse folders" : "Maletendi dosierujojn",
     "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
     "Mark all as read" : "Marki ĉion kiel legita",
-    "Mark all messages of this folder as read" : "Marki ĉiujn mesaĝojn el tiu dosierujo kiel legitaj",
     "Add subfolder" : "Aldoni subdosierujon",
     "Rename" : "Alinomi",
     "Clear cache" : "Forviŝi la kaŝmemoron",
@@ -136,7 +133,6 @@ OC.L10N.register(
     "Date" : "Date",
     "Tags" : "Etikedoj",
     "Select tags" : "Elekti etikedojn",
-    "Last 7 days" : "Lastaj 7 tagoj",
     "Custom" : "Propra",
     "Save signature" : "Konservi subskribon",
     "Delete tag" : "Forigi etikedon",
@@ -152,6 +148,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} de {depStation} al {arrStation}",
     "Train from {depStation} to {arrStation}" : "Trajno de {depStation} al {arrStation}",
     "Train" : "Trajno",
+    "Deleted" : "Forigita",
     "Recipient" : "Ricevonto",
     "Help" : "Helpo",
     "matches" : "kongruas kun",
@@ -180,7 +177,6 @@ OC.L10N.register(
     "Connect your mail account" : "Konekti vian retpoŝtan konton",
     "All" : "Ĉiuj",
     "Drafts" : "Malnetujo",
-    "Favorites" : "Pliŝataĵoj",
     "All inboxes" : "Ĉiuj ricevujoj",
     "Inbox" : "Ricevujo",
     "Junk" : "Trudmesaĝujo",
@@ -200,14 +196,7 @@ OC.L10N.register(
     "Redirect" : "Alidirekto",
     "The link leads to %s" : "La ligilo iras al %s",
     "Continue to %s" : "Daŭrigi al %s",
-    "Accounts" : "Kontoj",
-    "Use Gravatar and favicon avatars" : "Uzi servon „Gravatar“ kaj avatarojn en retpaĝsimbolo",
-    "Register as application for mail links" : "Registriĝi kiel programeto por retpoŝtligiloj",
-    "Contact or email address …" : "Kontakto aŭ retpoŝtadreso …",
-    "Subject …" : "Temo …",
-    "Write message …" : "Verku mesaĝon …",
-    "Saving draft …" : "Konservado de malneto...",
-    "Loading …" : "Ŝargas …",
-    "Signature …" : "Subskribo …"
+    "Mark all messages of this folder as read" : "Marki ĉiujn mesaĝojn el tiu dosierujo kiel legitaj",
+    "Last 7 days" : "Lastaj 7 tagoj"
 },
 "nplurals=2; plural=(n != 1);");
