@@ -34,9 +34,7 @@ OC.L10N.register(
     "Sorting" : "Orden",
     "Newest first" : "El más reciente primero",
     "Oldest first" : "Los más viejos primero",
-    "Register" : "Registrar",
     "Security" : "Seguridad",
-    "Keyboard shortcuts" : "Atajos de teclado",
     "Compose new message" : "Redactar nuevo mensaje",
     "Newer message" : "Mensaje mas nuevo",
     "Older message" : "Mensaje anterior",
@@ -65,9 +63,9 @@ OC.L10N.register(
     "Decline" : "Declinar",
     "More options" : "Más opciones",
     "Remove" : "Borrar",
-    "email" : "correo electrónico",
     "Today" : "Hoy",
     "Choose target folder" : "Elegir carpeta destino",
+    "Favorites" : "Favoritos",
     "Other" : "Otro",
     "Forward" : "Reenviar",
     "Translate" : "Traducir",
@@ -101,6 +99,7 @@ OC.L10N.register(
     "Tag already exists" : "La etiqueta ya existe",
     "Add tag" : "Añadir etiqueta",
     "Not found" : "No encontrado",
+    "Deleted" : "Eliminado",
     "Recipient" : "Recipiente",
     "Help" : "Ayuda",
     "contains" : "contiene",
@@ -125,7 +124,6 @@ OC.L10N.register(
     "Connect your mail account" : "Conecte su cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
-    "Favorites" : "Favoritos",
     "All inboxes" : "Todos los buzones de entrada",
     "Inbox" : "Buzón de entrada",
     "Junk" : "Basura",
@@ -143,7 +141,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haga click aqui si no es redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "El link lleva a %s",
-    "Continue to %s" : "Continuar a %s",
-    "Accounts" : "Accounts"
+    "Continue to %s" : "Continuar a %s"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
