@@ -32,9 +32,8 @@ OC.L10N.register(
     "Add mail account" : "Agregar cuenta de correo",
     "Newest first" : "Más reciente primero",
     "Oldest first" : "Más antiguo primero",
-    "Register" : "Registrar",
     "Security" : "Seguridad",
-    "Keyboard shortcuts" : "Atajos del teclado",
+    "About" : "Acerca",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
     "Older message" : "Mensaje más antiguo",
@@ -45,7 +44,6 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Enviar",
     "Refresh" : "Actualizar",
-    "About" : "Acerca",
     "Ok" : "Ok",
     "Select account" : "Selecciona la cuenta",
     "Subject" : "Asunto",
@@ -70,8 +68,8 @@ OC.L10N.register(
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Remove" : "Eliminar",
-    "email" : "correo electrónico",
     "Today" : "Hoy",
+    "Favorites" : "Favoritos",
     "Other" : "Otro",
     "Forward" : "Adelante",
     "Translate" : "Traducir",
@@ -102,6 +100,7 @@ OC.L10N.register(
     "Select tags" : "Selecciona las etiquetas",
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
+    "Deleted" : "Borrado",
     "Recipient" : "Destinatario",
     "Help" : "Ayuda",
     "matches" : "coincide",
@@ -124,7 +123,6 @@ OC.L10N.register(
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
-    "Favorites" : "Favoritos",
     "All inboxes" : "Todos los buzones de entrada",
     "Inbox" : "Buzón de entrada",
     "Junk" : "Basura",
@@ -143,8 +141,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s",
-    "Accounts" : "Accounts",
-    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon"
+    "Continue to %s" : "Continuar a %s"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
