@@ -113,26 +113,20 @@ OC.L10N.register(
     "Mail settings" : "Configuración de correo",
     "General" : "General",
     "Add mail account" : "Agregar cuenta de correo",
-    "Settings for:" : "Configuraciones para:",
     "Appearance" : "Apariencia",
     "Layout" : "Disposición",
-    "List" : "Lista",
     "Vertical split" : "División vertical",
     "Horizontal split" : "División horizontal",
+    "List" : "Lista",
     "Sorting" : "Ordenando",
     "Newest first" : "Más reciente primero",
     "Oldest first" : "Más antiguo primero",
-    "Search in body" : "Buscar cuerpo",
-    "Gravatar settings" : "Ajustes de Gravatar",
-    "Mailto" : "Mailto",
-    "Register" : "Registrar",
-    "Privacy and security" : "Privacidad y seguridad",
+    "Privacy" : "Privacidad",
     "Security" : "Seguridad",
-    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Resalta direcciones de correo electrónico externas al activar esta característica, administra tus direcciones internas y dominios para asegurar que los contactos reconocidos permanezcan sin resaltar.",
     "S/MIME" : "S/MIME",
     "Mailvelope" : "Mailvelope",
     "Assistance features" : "Características de asistencia",
-    "Keyboard shortcuts" : "Atajos del teclado",
+    "About" : "Acerca",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
     "Older message" : "Mensaje más antiguo",
@@ -143,7 +137,6 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Enviar",
     "Refresh" : "Actualizar",
-    "About" : "Acerca",
     "No certificate" : "Sin certificado",
     "Certificate updated" : "Certificado actualizado",
     "Could not update certificate" : "No se pudo actualizar el certificado",
@@ -277,7 +270,6 @@ OC.L10N.register(
     "individual" : "individual",
     "domain" : "dominio",
     "Remove" : "Eliminar",
-    "email" : "correo electrónico",
     "Add internal address" : "Agregar dirección interna",
     "Add internal email or domain" : "Agregar dirección de correo interna o dominio",
     "Itinerary for {type} is not supported yet" : "El itinerario para {type} aún no es soportado",
@@ -288,6 +280,7 @@ OC.L10N.register(
     "Last month" : "Mes pasado",
     "Choose target folder" : "Elegir carpeta destino",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
+    "Favorites" : "Favoritos",
     "Follow up" : "Seguimiento",
     "Follow up info" : "Información de seguimiento",
     "Important info" : "Información importante",
@@ -332,7 +325,6 @@ OC.L10N.register(
     "Date" : "Fecha",
     "Tags" : "Etiquetas",
     "Select tags" : "Selecciona las etiquetas",
-    "Last 7 days" : "Últimos 7 días",
     "Custom" : "Personalizado",
     "Tag already exists" : "La etiqueta ya existe",
     "Add tag" : "Añadir etiqueta",
@@ -340,6 +332,7 @@ OC.L10N.register(
     "Translate from" : "Traducir desde",
     "Untitled event" : "Evento sin título",
     "(organizer)" : "(organizador)",
+    "Deleted" : "Eliminado",
     "Recipient" : "Destinatario",
     "Help" : "Ayuda",
     "contains" : "contiene",
@@ -365,7 +358,6 @@ OC.L10N.register(
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
-    "Favorites" : "Favoritos",
     "All inboxes" : "Todos los buzones de entrada",
     "Inbox" : "Buzón de entrada",
     "Junk" : "Basura",
@@ -386,25 +378,6 @@ OC.L10N.register(
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
     "Continue to %s" : "Continuar a %s",
-    "Search in the body of messages in priority Inbox" : "Busca en el cuerpo de los mensajes de la bandeja de entrada prioritaria",
-    "Put my text to the bottom of a reply instead of on top of it." : "Pon el texto al fondo de una respuesta, en lugar de arriba.",
-    "Use internal addresses" : "Usar direcciones internas",
-    "Accounts" : "Cuentas",
-    "Newest" : "Más recientes",
-    "Oldest" : "Más antiguo",
-    "Reply text position" : "Posisión de respuesta del texto",
-    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
-    "Register as application for mail links" : "Registrar como aplicación para enlaces de correo electrónico",
-    "Data collection consent" : "Consentimiento de recolección de datos",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir que la aplicación recopile datos sobre tus interacciones. Con base en estos datos, la aplicación se adaptará a tus preferencias. Los datos se almacenarán solo localmente.",
-    "Trusted senders" : "Remitentes de confianza",
-    "Internal addresses" : "Direcciones internas",
-    "Manage S/MIME certificates" : "Administrar certificados S/MIME",
-    "Contact or email address …" : "Contacto o dirección de correo electrónico...",
-    "Subject …" : "Asunto...",
-    "Write message …" : "Redactar mensaje...",
-    "Saving draft …" : "Guardando borrador...",
-    "Loading messages …" : "Cargando mensajes...",
-    "Loading …" : "Cargando …"
+    "Last 7 days" : "Últimos 7 días"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
