@@ -127,6 +127,8 @@ OC.L10N.register(
     "Appearance" : "Välimus",
     "Show all messages in thread" : "Näita kõiki kirju jutulõngas",
     "When off, only the selected message will be shown" : "Kui eelistus pole kasutusel, siis näidatakse vaid valitud kirja",
+    "Sort favorites up" : "Järjesta lemmikud esimesena",
+    "When on, favorite messages will be sorted to the top of folders" : "Kui see valik on kasutusel, siis lemmikud järjestuvad kaustas esimestena",
     "Layout" : "Välimus",
     "Vertical split" : "Püstjoones jagamine",
     "Horizontal split" : "Rõhtjoones jagamine",
@@ -363,7 +365,10 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger folders." : "Indekseerin sinu kirju. Kui kaustad on väga suured, siis võib kuluda natuke aega.",
     "Choose target folder" : "Vali sihtkaust",
     "No more submailboxes in here" : "Siin poel rohkem alampostkaste",
+    "Messages that your mark as favorite will be shown at the top of folders. You can disable this behavior in the app settings" : "Lemmikuks märgitud kirjad järjestuvad kaustas esimestena. Selle valiku saad seadistustest välja lülitada.",
     "Favorites" : "Lemmikud",
+    "Favorites info" : "Lemmikute teave",
+    "Load more favorites" : "Laadi veel lemmikuid",
     "Load more follow ups" : "Laadi veel jätkukirju",
     "Important info" : "Oluline teave",
     "Load more important messages" : "Laadi veel olulisi kirju",
