@@ -12,8 +12,11 @@ OC.L10N.register(
     "To Do" : "Tehtävä",
     "Later" : "Myöhemmin",
     "Mail" : "Sähköposti",
+    "You are reaching your mailbox quota limit for {account_email}" : "Postilaatikon kiintiöraja tilille {account_email} lähenee",
+    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Postilaatikkosi tallennustilasta on tällä hetkellä käytössä {percentage}. Vapauta tilaa poistamalla tarpeettomia sähköposteja.",
     "Mail Application" : "Sähköpostisovellus",
     "Mails" : "Sähköpostit",
+    "Mail connection performance" : "Sähköpostiyhteyden suorituskyky",
     "💌 A mail app for Nextcloud" : "💌 Sähköpostisovellus Nextcloudille",
     "Your session has expired. The page will be reloaded." : "Istuntosi on vanhentunut. Sivu ladataan uudelleen.",
     "Drafts are saved in:" : "Luonnokset tallennetaan sijaintiin:",
@@ -102,9 +105,14 @@ OC.L10N.register(
     "New text block" : "Uusi tekstilohko",
     "Shared with me" : "Jaettu kanssasi",
     "Privacy" : "Yksityisyys",
+    "Data collection" : "Tiedonkeruu",
     "Security" : "Tietoturva",
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Hallitse varmenteita",
+    "Step 1" : "Vaihe 1",
+    "Install the browser extension" : "Asenna selainlaajennus",
+    "Step 2" : "Vaihe 2",
+    "Enable for the current domain" : "Ota käyttöön nykyiselle verkkotunnukselle",
     "About" : "Tietoja",
     "Compose new message" : "Uusi viesti",
     "Newer message" : "Uudempi",
@@ -138,12 +146,16 @@ OC.L10N.register(
     "Select account" : "Valitse tili",
     "To" : "Vastaanottaja",
     "Select recipient" : "Valitse vastaanottaja",
+    "Contact or email address …" : "Yhteystieto tai sähköpostiosoite …",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Aihe",
+    "Subject …" : "Aihe …",
     "This message came from a noreply address so your reply will probably not be read." : "Tämä viesti saapui noreply-osoitteesta, joten vastaustasi ei luultavasti lueta.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "Seuraavilla vastaanottajilla ei ole S/MIME-varmennetta: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "Seuraavilla vastaanottajilla ei ole PGP-avainta: {recipients}.",
+    "Write message …" : "Kirjoita viesti …",
+    "Saving draft …" : "Tallennetaan luonnosta …",
     "Error saving draft" : "Virhe tallentaessa luonnosta",
     "Draft saved" : "Luonnos tallennettu",
     "Save draft" : "Tallenna luonnos",
@@ -223,6 +235,7 @@ OC.L10N.register(
     "_Move {number} thread_::_Move {number} threads_" : ["Siirrä {number} ketju","Siirrä {number} ketjua"],
     "Mark as unread" : "Merkitse lukemattomaksi",
     "Mark as read" : "Merkitse luetuksi",
+    "Mark as important" : "Merkitse tärkeäksi",
     "Report this bug" : "Ilmoita viasta",
     "Event created" : "Tapahtuma luotu",
     "Could not create event" : "Tapahtumaa ei voitu luoda",
@@ -261,6 +274,8 @@ OC.L10N.register(
     "Last week" : "Viime viikko",
     "Last month" : "Viime kuukausi",
     "Could not open folder" : "Kansiota ei voitu avata",
+    "Loading messages …" : "Ladataan viestejä …",
+    "Indexing your messages. This can take a bit longer for larger folders." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisten kansioiden kohdalla.",
     "Choose target folder" : "Valitse kohdekansio",
     "Favorites" : "Suosikit",
     "Important info" : "Tärkeää tietoa",
@@ -279,11 +294,13 @@ OC.L10N.register(
     "Message body" : "Viestin runko",
     "Unnamed" : "Nimetön",
     "Embedded message" : "Upotettu viesti",
+    "Attachment could not be saved" : "Liitettä ei voitu tallentaa",
     "calendar imported" : "kalenteri tuotu",
     "Choose a folder to store the attachment in" : "Valitse kansio liitetiedoston tallentamiselle",
     "Import into calendar" : "Tuo kalenteriin",
     "Download attachment" : "Lataa liite",
     "Save to Files" : "Tallenna tiedostoihin",
+    "Error while saving attachments" : "Virhe liitteitä tallentaessa",
     "View fewer attachments" : "Näytä vähemmän liitteitä",
     "Choose a folder to store the attachments in" : "Valitse kansio johon liitteet tallennetaan",
     "Save all to Files" : "Tallenna kaikki tiedostoihin",
@@ -301,6 +318,7 @@ OC.L10N.register(
     "Moving" : "Siirretään",
     "Moving thread" : "Siirretään ketjua",
     "Moving message" : "Siirretään viestiä",
+    "This account cannot connect" : "Tämä tili ei voi yhdistää",
     "Used quota: {quota}% ({limit})" : "Käytetty kiintiö: {quota}% ({limit})",
     "Used quota: {quota}%" : "Käytetty kiintiö: {quota}%",
     "Remove account" : "Poista tili",
@@ -317,6 +335,7 @@ OC.L10N.register(
     "Collapse folders" : "Supista kansiot",
     "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lukematonta {total} viestistä","{unread} lukematonta {total} viestistä"],
+    "Loading …" : "Ladataan …",
     "All messages in mailbox will be deleted." : "Kaikki postilaatikon viestit poistetaan.",
     "Clear mailbox {name}" : "Tyhjennä postilaatikko {name}",
     "The folder and all messages in it will be deleted." : "Tämä kansio ja kaikki sen viestit poistetaan.",
@@ -327,6 +346,7 @@ OC.L10N.register(
     "Add subfolder" : "Lisää alikansio",
     "Rename" : "Nimeä uudelleen",
     "Move folder" : "Siirrä kansio",
+    "Repair folder" : "Korjaa kansio",
     "Clear cache" : "Tyhjennä välimuisti",
     "Clear locally cached data, in case there are issues with synchronization." : "Poista paikallisesti tallennetut tiedot, jos synkronoinnissa on ongelmia.",
     "Subscribed" : "Tilattu",
@@ -390,6 +410,7 @@ OC.L10N.register(
     "Sieve Password" : "Sieve-salasana",
     "Save sieve settings" : "Tallenna sieve-asetukset",
     "The syntax seems to be incorrect:" : "Syntaksi vaikuttaa virheelliseltä:",
+    "Signature …" : "Allekirjoitus …",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Allekirjoituksesi koko on yli kaksi megatavua. Tämä saattaa vaikuttaa muokkaimen suorituskykyyn.",
     "Save signature" : "Tallenna allekirjoitus",
     "Place signature above quoted text" : "Aseta allekirjoitus lainatun tekstin yläpuolelle",
@@ -468,6 +489,7 @@ OC.L10N.register(
     "Help" : "Ohje",
     "contains" : "sisältää",
     "matches" : "täsmää",
+    "Conditions" : "Ehdot",
     "Add condition" : "Lisää ehto",
     "Actions" : "Toiminnot",
     "Add action" : "Lisää toiminto",
