@@ -57,13 +57,14 @@ OC.L10N.register(
     "General" : "כללי",
     "Add mail account" : "הוספת חשבון דוא״ל",
     "Appearance" : "מראה",
+    "List" : "רשימה",
     "Sorting" : "מיון",
     "Newest first" : "החדש ביותר ראשון",
     "Oldest first" : "הישן ביותר ראשון",
-    "Register" : "רישום",
+    "Privacy" : "פרטיות",
     "Security" : "אבטחה",
     "Manage certificates" : "ניהול אישורים",
-    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "About" : "אודות",
     "Compose new message" : "כתיבת הודעה חדשה",
     "Newer message" : "הודעה חדשה יותר",
     "Older message" : "הודעה ישנה יותר",
@@ -74,7 +75,6 @@ OC.L10N.register(
     "Search" : "חיפוש",
     "Send" : "שליחה",
     "Refresh" : "רענון",
-    "About" : "אודות",
     "Ok" : "אישור",
     "Message {id} could not be found" : "לא ניתן למצוא את הודעה {id}",
     "From" : "מאת",
@@ -104,6 +104,7 @@ OC.L10N.register(
     "Could not delete message" : "לא ניתן למחוק הודעה",
     "Unfavorite" : "ביטול כמועדף",
     "Favorite" : "סימון כמועדף",
+    "Unread" : "לא נקרא",
     "Read" : "קריאה",
     "Mark not spam" : "לסמן שזה לא ספאם",
     "Mark as spam" : "לסמן כספאם",
@@ -131,7 +132,6 @@ OC.L10N.register(
     "individual" : "יחיד",
     "domain" : "שם תחום",
     "Remove" : "הסרה",
-    "email" : "דוא״ל",
     "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
     "Last hour" : "השעה החולפת",
     "Today" : "היום",
@@ -139,6 +139,7 @@ OC.L10N.register(
     "Last week" : "שבוע שעבר",
     "Last month" : "חודש שעבר",
     "Choose target folder" : "נא לבחור תיקיית יעד",
+    "Favorites" : "מועדפים",
     "Important info" : "מידע חשוב",
     "Other" : "אחר",
     "Forward" : "העברה",
@@ -171,7 +172,6 @@ OC.L10N.register(
     "Delete folder" : "מחק תיקייה",
     "An error occurred, unable to rename the mailbox." : "אירעה שגיאה, לא ניתן לשנות את שם תיבת הדוא״ל.",
     "Mark all as read" : "סימון הכול כנקרא",
-    "Mark all messages of this folder as read" : "סימון כל ההודעות בתיקייה הזאת כנקראו",
     "Add subfolder" : "הוספת תת־תיקייה",
     "Rename" : "שינוי שם",
     "Clear cache" : "פינוי מטמון",
@@ -214,6 +214,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} מ־{depStation} אל {arrStation}",
     "Train from {depStation} to {arrStation}" : "רכבת מ־{depStation} אל {arrStation}",
     "Train" : "רכבת",
+    "Deleted" : "נמחק",
     "Help" : "עזרה",
     "matches" : "תואם",
     "Actions" : "פעולות",
@@ -249,7 +250,6 @@ OC.L10N.register(
     "Connect your mail account" : "התחברות לחשבון הדוא״ל שלך",
     "All" : "הכול",
     "Drafts" : "טיוטות",
-    "Favorites" : "מועדפים",
     "Priority inbox" : "תיבת דואר נכנס בעדיפות",
     "All inboxes" : "כל תיבות דואר נכנס",
     "Inbox" : "דואר נכנס",
@@ -273,17 +273,6 @@ OC.L10N.register(
     "Redirect" : "הפנייה",
     "The link leads to %s" : "הקישור מוביל אל %s",
     "Continue to %s" : "ממשיך אל %s",
-    "Accounts" : "Accounts",
-    "Use Gravatar and favicon avatars" : "להשתמש בסמלים של Gravatar ושל favicon",
-    "Register as application for mail links" : "רישום כיישום לטיפול בקישורי דוא״ל (mailto)",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "לאפשר ליישומן לאסוף נתונים על אופן השימוש שלך. על בסיס המידע הזה, היישומון יתאים את עצמו להעדפות שלך. הנתונים יישמרו מקומית בלבד.",
-    "Trusted senders" : "שולחים מהימנים",
-    "Contact or email address …" : "איש קשר או כתובת דוא״ל…",
-    "Subject …" : "נושא…",
-    "Write message …" : "כתיבת הודעה…",
-    "Saving draft …" : "הטיוטה נשמרת…",
-    "Loading …" : "בטעינה",
-    "Signature …" : "חתימה…",
-    "Saving tag …" : "התגית נשמרת…"
+    "Mark all messages of this folder as read" : "סימון כל ההודעות בתיקייה הזאת כנקראו"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
