@@ -103,14 +103,12 @@ OC.L10N.register(
     "Sorting" : "Sorting",
     "Newest first" : "Newest first",
     "Oldest first" : "Oldest first",
-    "Gravatar settings" : "Gravatar settings",
-    "Mailto" : "Mailto",
-    "Register" : "Register",
     "Shared with me" : "Shared with me",
+    "Privacy" : "Privacy",
     "Security" : "Security",
     "S/MIME" : "S/MIME",
     "Mailvelope" : "Mailvelope",
-    "Keyboard shortcuts" : "Keyboard shortcuts",
+    "About" : "About",
     "Compose new message" : "Compose new message",
     "Newer message" : "Newer message",
     "Older message" : "Older message",
@@ -121,7 +119,6 @@ OC.L10N.register(
     "Search" : "Search",
     "Send" : "Send",
     "Refresh" : "Refresh",
-    "About" : "About",
     "Ok" : "Ok",
     "No certificate" : "No certificate",
     "Certificate updated" : "Certificate updated",
@@ -268,7 +265,6 @@ OC.L10N.register(
     "individual" : "individual",
     "domain" : "domain",
     "Remove" : "Remove",
-    "email" : "email",
     "Itinerary for {type} is not supported yet" : "Itinerary for {type} is not supported yet",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
     "Today" : "დღეს",
@@ -278,6 +274,7 @@ OC.L10N.register(
     "Choose target folder" : "Choose target folder",
     "No more submailboxes in here" : "No more submailboxes in here",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
+    "Favorites" : "Favorites",
     "Important info" : "Important info",
     "Other" : "Other",
     "Could not send mdn" : "Could not send mdn",
@@ -401,7 +398,6 @@ OC.L10N.register(
     "Select tags" : "Select tags",
     "Marked as" : "Marked as",
     "Has attachments" : "Has attachments",
-    "Last 7 days" : "Last 7 days",
     "Enable mail body search" : "Enable mail body search",
     "Sieve Port" : "Sieve Port",
     "Custom" : "Custom",
@@ -475,6 +471,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} from {depStation} to {arrStation}",
     "Train from {depStation} to {arrStation}" : "Train from {depStation} to {arrStation}",
     "Train" : "Train",
+    "Deleted" : "Deleted",
     "Help" : "Help",
     "matches" : "matches",
     "Actions" : "Actions",
@@ -590,7 +587,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "To add a mail account, please contact your administrator.",
     "All" : "All",
     "Drafts" : "Drafts",
-    "Favorites" : "Favorites",
     "Priority inbox" : "Priority inbox",
     "All inboxes" : "All inboxes",
     "Inbox" : "Inbox",
@@ -622,27 +618,6 @@ OC.L10N.register(
     "The link leads to %s" : "The link leads to %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "Continue to %s",
-    "Search in the body of messages in priority Inbox" : "Search in the body of messages in priority Inbox",
-    "Put my text to the bottom of a reply instead of on top of it." : "Put my text to the bottom of a reply instead of on top of it.",
-    "Accounts" : "Accounts",
-    "Newest" : "Newest",
-    "Oldest" : "Oldest",
-    "Reply text position" : "Reply text position",
-    "Use Gravatar and favicon avatars" : "Use Gravatar and favicon avatars",
-    "Register as application for mail links" : "Register as application for mail links",
-    "Data collection consent" : "Data collection consent",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
-    "Trusted senders" : "Trusted senders",
-    "Manage S/MIME certificates" : "Manage S/MIME certificates",
-    "Contact or email address …" : "Contact or email address …",
-    "Subject …" : "Subject …",
-    "Write message …" : "Write message …",
-    "Saving draft …" : "Saving draft …",
-    "Loading messages …" : "Loading messages …",
-    "Loading …" : "Loading …",
-    "Contact name …" : "Contact name …",
-    "Signature …" : "Signature …",
-    "Saving new tag name …" : "Saving new tag name …",
-    "Saving tag …" : "Saving tag …"
+    "Last 7 days" : "Last 7 days"
 },
 "nplurals=2; plural=(n!=1);");
