@@ -32,9 +32,8 @@ OC.L10N.register(
     "Add mail account" : "საფოსტო ანგარიშის დამატება",
     "Newest first" : "ჯერ ახალი",
     "Oldest first" : "ჯერ ძველი",
-    "Register" : "რეგისტრაცია",
     "Security" : "უსაფრთხოება",
-    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
+    "About" : "ჩვენს შესახებ",
     "Compose new message" : "ახალი წერილის შედგენა",
     "Newer message" : "უფრო ახალი წერილი",
     "Older message" : "ძველი წერილი",
@@ -45,7 +44,6 @@ OC.L10N.register(
     "Search" : "ძიება",
     "Send" : "გაგზავნა",
     "Refresh" : "განახლება",
-    "About" : "ჩვენს შესახებ",
     "Ok" : "კარგი",
     "Select account" : "აირჩიეთ ანგარიში",
     "Subject" : "სათაური",
@@ -71,8 +69,8 @@ OC.L10N.register(
     "Accept" : "მიღება",
     "Decline" : "ურაყოფა",
     "Remove" : "წაშლა",
-    "email" : "ელ-ფოსტა",
     "Today" : "დღეს",
+    "Favorites" : "რჩეულები",
     "Other" : "სხვა",
     "Forward" : "წინ",
     "Translate" : "გადათარგმნეთ",
@@ -106,6 +104,7 @@ OC.L10N.register(
     "Select tags" : "აირჩიეთ ტეგები",
     "Custom" : "ინდივიდუალური",
     "Add tag" : "ტეგის დამატება",
+    "Deleted" : "გაუქმდა",
     "Recipient" : "მიმღები",
     "Help" : "დახმარება",
     "matches" : "ემთხვევა",
@@ -126,7 +125,6 @@ OC.L10N.register(
     "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
     "All" : "ყველა",
     "Drafts" : "მონახაზები",
-    "Favorites" : "რჩეულები",
     "All inboxes" : "ყველა ინბოქსი",
     "Inbox" : "ინბოქსი",
     "Junk" : "უსარგებლო",
@@ -146,8 +144,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "იმ შემთხვევაში, თუ რამდენიმე წამის განმავლობაში არ მოხდება ავტომატური გადამისამართება დააწკაპუნეთ აქ.",
     "Redirect" : "გადამისამართება",
     "The link leads to %s" : "ბმულს მიყევხართ %s-ისკენ",
-    "Continue to %s" : "%s-ისკენ გაგრძელება",
-    "Accounts" : "ანგარიში",
-    "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები"
+    "Continue to %s" : "%s-ისკენ გაგრძელება"
 },
 "nplurals=2; plural=(n!=1);");
