@@ -84,12 +84,11 @@ OC.L10N.register(
     "Sorting" : "Rikiavimas",
     "Newest first" : "Naujausi pirma",
     "Oldest first" : "Seniausi pirma",
-    "Register" : "Registruotis",
-    "Privacy and security" : "Privatumas ir saugumas",
+    "Privacy" : "Privatumas",
     "Security" : "Saugumas",
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Tvarkyti liudijimus",
-    "Keyboard shortcuts" : "Spartieji klavišai",
+    "About" : "Apie",
     "Compose new message" : "Rašyti naują laišką",
     "Newer message" : "Naujesni laiškai",
     "Older message" : "Senesni laiškai",
@@ -100,7 +99,6 @@ OC.L10N.register(
     "Search" : "Ieškoti",
     "Send" : "Siųsti",
     "Refresh" : "Įkelti iš naujo",
-    "About" : "Apie",
     "Ok" : "Gerai",
     "Certificate updated" : "Liudijimas atnaujintas",
     "Could not update certificate" : "Nepavyko atnaujinti liudijimo",
@@ -200,13 +198,13 @@ OC.L10N.register(
     "Could not remove internal address {sender}" : "Nepavyko pašalinti vidinio adreso {sender}",
     "Could not add internal address {address}" : "Nepavyko pridėti vidinį adresą {address}",
     "Remove" : "Šalinti",
-    "email" : "elektroninis paštas",
     "Add internal address" : "Pridėti vidinį adresą",
     "Last hour" : "Paskutinė valanda",
     "Today" : "Šiandien",
     "Last week" : "Praeitą savaitę",
     "Last month" : "Praeitą mėnesį",
     "Choose target folder" : "Pasirinkite paskirties aplanką",
+    "Favorites" : "Mėgstami",
     "Important info" : "Svarbi informacija",
     "Other" : "Kita",
     "The sender of this message has asked to be notified when you read this message." : "Šio laiško siuntėjas paprašė, kad jam būtų pranešta, kai perskaitysite šį laišką.",
@@ -259,13 +257,13 @@ OC.L10N.register(
     "Delete folder {name}" : "Ištrinti aplanką {name}",
     "An error occurred, unable to rename the mailbox." : "Įvyko klaida, nepavyko pervadinti pašto dėžutės.",
     "Mark all as read" : "Žymėti visus kaip skaitytus",
-    "Mark all messages of this folder as read" : "Žymėti visus laiškus šiame aplanke kaip skaitytus",
     "Add subfolder" : "Pridėti poaplankį",
     "Rename" : "Pervadinti",
     "Move folder" : "Perkelti aplanką",
     "Clear cache" : "Išvalyti podėlį",
     "Subscribed" : "Prenumeruotas",
     "Sync in background" : "Sinchronizuoti fone",
+    "Delete all messages" : "Ištrinti visas žinutes",
     "New message" : "Naujas laiškas",
     "Edit message" : "Taisyti laišką",
     "Draft" : "Juodraštis",
@@ -302,7 +300,6 @@ OC.L10N.register(
     "Date" : "Data",
     "Tags" : "Žymos",
     "Select tags" : "Pasirinkti žymas",
-    "Last 7 days" : "Paskutinės 7 dienos",
     "Custom" : "Tinkinti",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Jūsų parašas yra didesnis nei 2 MB. Tai gali paveikti redaktoriaus našumą.",
     "Save signature" : "Įrašyti parašą",
@@ -340,6 +337,7 @@ OC.L10N.register(
     "Train" : "Traukinys",
     "Stop" : "Stabdyti",
     "Delete action" : "Ištrinti veiksmą",
+    "Deleted" : "Ištrinta",
     "Recipient" : "Gavėjas",
     "Delete filter" : "Ištrinti filtrą",
     "Delete mail filter {filterName}?" : "Ištrinti pašto filtrą {filterName}?",
@@ -409,7 +407,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "Norėdami pridėti pašto paskyrą, susisiekite su savo administratoriumi.",
     "All" : "Visos",
     "Drafts" : "Juodraščiai",
-    "Favorites" : "Mėgstami",
     "All inboxes" : "Visos pašto dėžutės",
     "Inbox" : "Gauta",
     "Junk" : "Šlamštas",
@@ -436,24 +433,7 @@ OC.L10N.register(
     "Redirect" : "Peradresuoti",
     "The link leads to %s" : "Nuoroda veda į %s",
     "Continue to %s" : "Tęsti į %s",
-    "Use internal addresses" : "Naudoti vidinius adresus",
-    "Accounts" : "Paskyros",
-    "Newest" : "Naujausios",
-    "Oldest" : "Seniausios",
-    "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
-    "Register as application for mail links" : "Registruoti kaip pašto nuorodų programėlę",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Leisti programėlei rinkti duomenis apie jūsų sąveikas. Remiantis šiais duomenimis, programėlė prisitaikys prie jūsų nuostatų. Duomenys bus laikomi tik vietoje.",
-    "Trusted senders" : "Patikimi siuntėjai",
-    "Internal addresses" : "Vidiniai adresai",
-    "Manage S/MIME certificates" : "Tvarkyti S/MIME liudijimus",
-    "Contact or email address …" : "Adresatas ar el. pašto adresas…",
-    "Subject …" : "Tema…",
-    "Write message …" : "Rašykite laišką…",
-    "Saving draft …" : "Įrašomas juodraštis…",
-    "Loading messages …" : "Įkeliami laiškai…",
-    "Loading …" : "Įkeliama…",
-    "Contact name …" : "Adresato vardas…",
-    "Signature …" : "Parašas…",
-    "Saving tag …" : "Įrašoma žyma…"
+    "Mark all messages of this folder as read" : "Žymėti visus laiškus šiame aplanke kaip skaitytus",
+    "Last 7 days" : "Paskutinės 7 dienos"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
