@@ -52,8 +52,8 @@ OC.L10N.register(
     "Appearance" : "Izskats",
     "Newest first" : "Jaunākie pirms",
     "Oldest first" : "Vecākie pirms",
+    "Privacy" : "Privātums",
     "Security" : "Drošība",
-    "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Archive" : "Arhīvi",
     "Delete" : "Izdzēst",
     "Search" : "Meklēt",
@@ -89,9 +89,9 @@ OC.L10N.register(
     "Decline" : "Noraidīt",
     "More options" : "Vairāk iespēju",
     "Remove" : "Noņemt",
-    "email" : "e-pasts",
     "Today" : "Šodien",
     "Could not open folder" : "Nevarēja atvērt mapi",
+    "Favorites" : "Izlases vienumi",
     "Other" : "Cits",
     "The sender of this message has asked to be notified when you read this message." : "Šī ziņojuma sūtītājs ir norādījis, ka vēlas saņemt paziņojumu par šī ziņojuma izlasīšanu.",
     "Forward" : "Turpināt",
@@ -132,7 +132,6 @@ OC.L10N.register(
     "Date" : "Datums",
     "Tags" : "Birkas",
     "Select tags" : "Atlasīt birkas",
-    "From me" : "No manis",
     "Custom" : "Pielāgots",
     "An error occurred, unable to rename the tag." : "Atgadījās kļūda, nevar pārdēvēt birku.",
     "Delete tag" : "Izdzēst birku",
@@ -140,6 +139,7 @@ OC.L10N.register(
     "Tag already exists" : "Birka jau pastāv",
     "Not found" : "Nav atrasts",
     "Untitled event" : "Nenosaukts notikums",
+    "Deleted" : "Izdzēsts",
     "Recipient" : "Saņēmējs",
     "Help" : "Palīdzība",
     "contains" : "saturs",
@@ -149,7 +149,6 @@ OC.L10N.register(
     "Tag" : "Birkas",
     "delete" : "dzēst",
     "Edit" : "Labot",
-    "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu",
     "Reset" : "Atiestatīt",
     "Client ID" : "Klienta ID",
     "User" : "Lietotājs",
@@ -158,6 +157,7 @@ OC.L10N.register(
     "Valid until" : "Derīgs līdz",
     "Certificate" : "Sertifikāts",
     "Submit" : "Iesniegt",
+    "Guest" : "Viesis",
     "Group" : "Grupa",
     "Shared" : "Koplietots",
     "Shares" : "Koplietots",
@@ -166,7 +166,6 @@ OC.L10N.register(
     "Connect your mail account" : "Pievienot savu e-pasta kontu",
     "All" : "Visi",
     "Drafts" : "Melnraksti",
-    "Favorites" : "Izlases vienumi",
     "All inboxes" : "Visas iesūtnes",
     "Inbox" : "Iesūtne",
     "Junk" : "Nevēlams",
@@ -184,8 +183,7 @@ OC.L10N.register(
     "Redirect" : "Novirzīt",
     "The link leads to %s" : "Saite, kas ved uz %s",
     "Continue to %s" : "Turpināt %s",
-    "Accounts" : "Konti",
-    "Write message …" : "Rakstiet ziņu...",
-    "Loading …" : "Ielādē…"
+    "From me" : "No manis",
+    "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
