@@ -90,22 +90,18 @@ OC.L10N.register(
     "Mail settings" : "Параметри за е-пошта",
     "General" : "Општо",
     "Add mail account" : "Додади е-пошта сметка",
-    "Settings for:" : "Параметри за:",
     "Appearance" : "Изглед",
     "Layout" : "Распоред",
-    "List" : "Листа",
     "Vertical split" : "Вертикална поделба",
     "Horizontal split" : "Хоризонтална поделба",
+    "List" : "Листа",
     "Sorting" : "Сортирање",
     "Newest first" : "Новите прво",
     "Oldest first" : "Старите прво",
-    "Search in body" : "Барај по пораката",
-    "Gravatar settings" : "Параметри за Gravatar ",
-    "Register" : "Регистрирај се",
-    "Privacy and security" : "Приватност и безбедност",
+    "Privacy" : "Приватност",
     "Security" : "Безбедност",
-    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Означете ги надворешните е-адреси со овозможување на оваа функција, управувајте со вашите внатрешни адреси и домени за да се осигурате дека препознаените контакти остануваат необележани.",
-    "Keyboard shortcuts" : "Кратенки преку тастатура",
+    "About" : "За",
+    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Оваа апликација го вклучува CKEditor, уредник со отворен код. Copyright © CKEditor contributors. Лиценцирано под GPLv2.",
     "Compose new message" : "Состави нова порака",
     "Newer message" : "Понови пораки",
     "Older message" : "Постари пораки",
@@ -116,8 +112,6 @@ OC.L10N.register(
     "Search" : "Барај",
     "Send" : "Прати",
     "Refresh" : "Освежи",
-    "About" : "За",
-    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Оваа апликација го вклучува CKEditor, уредник со отворен код. Copyright © CKEditor contributors. Лиценцирано под GPLv2.",
     "Ok" : "Во ред",
     "No certificate" : "Нема сертификат",
     "Certificate updated" : "Сертификатот е ажуриран",
@@ -235,7 +229,6 @@ OC.L10N.register(
     "individual" : "индивидуално",
     "domain" : "домен",
     "Remove" : "Отстрани ",
-    "email" : "е-пошта",
     "Add internal address" : "Додади внатрешна адреса",
     "Add internal email or domain" : "Додади внатрешна е-пошта или домен",
     "Itinerary for {type} is not supported yet" : "Итинерар за {type} сеуште не е поддржан",
@@ -244,6 +237,7 @@ OC.L10N.register(
     "Choose target folder" : "Избери папка",
     "No more submailboxes in here" : "Нема повеќе подсандачиња тука",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Пораките автоматски ќе бидат означени како важни врз основа на кои пораки сте комуницирале или сте ги означиле како важни. На почетокот можеби ќе треба рачно да ја менувате важноста да го научите системот, но тоа ќе се подобрува со текот на времето.",
+    "Favorites" : "Омилени",
     "Important info" : "Важна информација",
     "Other" : "Останато",
     "The sender of this message has asked to be notified when you read this message." : "Испраќачот на оваа порака посака да биде известен кога ќе ја прочитате оваа порака.",
@@ -300,7 +294,6 @@ OC.L10N.register(
     "An error occurred, unable to rename the mailbox." : "Настана грешка, неможе да се промени името на сандачето.",
     "Please wait 10 minutes before repairing again" : "Почекајте 10 минути пред повторно да поправите",
     "Mark all as read" : "Означи ги сите како прочитани",
-    "Mark all messages of this folder as read" : "Означи ги сите пораки во оваа папка како прочитани",
     "Add subfolder" : "Додади подпапка",
     "Rename" : "Преименувај",
     "Move folder" : "Премести папка",
@@ -354,7 +347,6 @@ OC.L10N.register(
     "Select tags" : "Избери ознаки",
     "Marked as" : "Означено како",
     "Has attachments" : "Има прилози",
-    "Last 7 days" : "Предходни 7 дена",
     "Sieve Port" : "Sieve порта",
     "Custom" : "Прилагодено",
     "Sieve User" : "Sieve корисник",
@@ -386,6 +378,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} од {depStation} до {arrStation}",
     "Train from {depStation} to {arrStation}" : "Воз од  {depStation} до {arrStation}",
     "Train" : "Воз",
+    "Deleted" : "Избришани",
     "Help" : "Помош",
     "matches" : "се совпаѓа",
     "Actions" : "Акции",
@@ -438,7 +431,6 @@ OC.L10N.register(
     "Connect your mail account" : "Поврзете ја вашата е-пошта сметка",
     "All" : "Сите",
     "Drafts" : "Шаблони",
-    "Favorites" : "Омилени",
     "Priority inbox" : "Приоритетно сандаче",
     "All inboxes" : "Сите сандачиња",
     "Inbox" : "Сандаче",
@@ -468,29 +460,7 @@ OC.L10N.register(
     "The link leads to %s" : "Линкот води кон %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Доколку несакате да ја посетите страната, можете да се вратите кон <a href=\"%s\">Е-пошта</a>.",
     "Continue to %s" : "Продолжи до %s",
-    "Search in the body of messages in priority Inbox" : "Барај во пораката во приоритетното сандаче",
-    "Put my text to the bottom of a reply instead of on top of it." : "Стави го мојот текст на дното од одговорот наместо врз него.",
-    "Use internal addresses" : "Користи внатрешни адреси",
-    "Accounts" : "Сметки",
-    "Newest" : "Најнови",
-    "Oldest" : "Најстари",
-    "Reply text position" : "Позиција на одговорот",
-    "Use Gravatar and favicon avatars" : "Користете Граватар и Фавикон аватари",
-    "Register as application for mail links" : "Регистрирај како апликација за отварање на е-пошта линкови ",
-    "Data collection consent" : "Согласност за собирање податоци",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволете апликацијата да собира податоци за вашите интеракции. Врз основа на овие податоци, апликацијата ќе се прилагоди на вашите потреби. Податоците ќе се зачувуваат само локално.",
-    "Trusted senders" : "Доверливи испраќачи",
-    "Internal addresses" : "Внатрешни адреси",
-    "Manage S/MIME certificates" : "Управувај со S/MIME серификатите",
-    "Contact or email address …" : "Контакт или е-пошта адреса ...",
-    "Subject …" : "Наслов ...",
-    "Write message …" : "Напиши порака ...",
-    "Saving draft …" : "Зачувување како нацрт ...",
-    "Loading messages …" : "Вчитување пораки ...",
-    "Loading …" : "Се вчитува…",
-    "Contact name …" : "Име на контакт ...",
-    "Signature …" : "Потпис ...",
-    "Saving new tag name …" : "Зачувување на ново име на ознака ...",
-    "Saving tag …" : "Зачувување ознака …"
+    "Mark all messages of this folder as read" : "Означи ги сите пораки во оваа папка како прочитани",
+    "Last 7 days" : "Предходни 7 дена"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
