@@ -112,24 +112,19 @@ OC.L10N.register(
     "Add mail account" : "Legg til e-postkonto",
     "Appearance" : "Utseende",
     "Layout" : "Utforming",
-    "List" : "Liste",
     "Vertical split" : "Loddrett deling",
     "Horizontal split" : "Horisontal deling",
+    "List" : "Liste",
     "Sorting" : "Sorter",
     "Newest first" : "Nyeste først",
     "Oldest first" : "Eldste først",
-    "Search in body" : "Søk i innholdstekst",
-    "Gravatar settings" : "Gravatar-innstillinger",
-    "Mailto" : "Mailto",
-    "Register" : "Registrer",
-    "Privacy and security" : "Personvern og sikkerhet",
+    "Privacy" : "Personvern",
     "Security" : "Sikkerhet",
-    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Fremhev eksterne e-postadresser ved å aktivere denne funksjonen, administrer dine interne adresser og domener for å sikre at gjenkjente kontakter forblir umerket.",
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Administrer sertifikat",
     "Mailvelope" : "Mailvelope",
     "Assistance features" : "Assistanse funksjoner",
-    "Keyboard shortcuts" : "Tastatursnarveier",
+    "About" : "Om",
     "Compose new message" : "Lag ny melding",
     "Newer message" : "Nyere melding",
     "Older message" : "Eldre melding",
@@ -140,7 +135,6 @@ OC.L10N.register(
     "Search" : "Søk",
     "Send" : "Send",
     "Refresh" : "Oppdater",
-    "About" : "Om",
     "Ok" : "Ok",
     "No certificate" : "Ingen sertifikat",
     "Certificate updated" : "Sertifikat oppdatert",
@@ -296,7 +290,6 @@ OC.L10N.register(
     "individual" : "individuell",
     "domain" : "domene",
     "Remove" : "Fjern",
-    "email" : "e-post",
     "Add internal address" : "Legg til intern adresse",
     "Add internal email or domain" : "Legg til intern e-post eller domene",
     "Itinerary for {type} is not supported yet" : "Reiserute for {type} støttes ikke ennå",
@@ -310,6 +303,7 @@ OC.L10N.register(
     "No more submailboxes in here" : "Ingen flere underpostbokser her",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meldinger blir automatisk merket som viktige basert på hvilke meldinger du har interagert med eller merket som viktige. I begynnelsen må du kanskje endre viktigheten manuelt for å lære systemet, men det vil forbedres over tid.",
     "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "Meldinger sendt av deg som krever svar, men ikke mottok en etter et par dager, vises her.",
+    "Favorites" : "Favoritter",
     "Follow up" : "Følg opp",
     "Follow up info" : "Følg opp info",
     "Important info" : "Viktig informasjon",
@@ -384,6 +378,7 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Slett lokalt bufrede data, i tilfelle det er problemer med synkronisering.",
     "Subscribed" : "Abonnerer",
     "Sync in background" : "Synkroniser i bakgrunnen",
+    "Delete all messages" : "Slett alle meldinger",
     "Outbox" : "Utboks",
     "New message" : "Ny melding",
     "Edit message" : "Rediger melding",
@@ -451,8 +446,6 @@ OC.L10N.register(
     "Marked as" : "Merket som",
     "Has attachments" : "Har vedlegg",
     "Has attachment" : "Har vedlegg",
-    "Last 7 days" : "Siste 7 dager",
-    "From me" : "Fra meg",
     "Enable mail body search" : "Aktiver søk i meldingsinnhold for e-post",
     "Sieve host" : "Sieve-tjener",
     "Sieve security" : "Sieve-sikkerhet",
@@ -535,6 +528,7 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}\n ",
     "Train" : "Tog",
     "Stop" : "Stoppe",
+    "Deleted" : "Slettet",
     "Recipient" : "Mottaker",
     "Delete filter" : "Slett filter",
     "Help" : "Hjelp",
@@ -552,7 +546,6 @@ OC.L10N.register(
     "There was an error when provisioning accounts." : "Det oppsto en feil under klargjøring av kontoene.",
     "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Vellykket slettet og deaktivert kontoer for «{domain}»",
     "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Feil ved sletting og deaktivering av kontoer for «{domain}»",
-    "Could not save default classification setting" : "Kan ikke lagre standard klassifiseringsinnstilling",
     "Mail app" : "E-post app",
     "The mail app allows users to read mails on their IMAP accounts." : "E-post appen lar brukere lese e-poster på IMAP-kontoene sine.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Her kan du finne innstillinger for hele instansen. Bruker spesifikke innstillinger finner du i selve appen (nederst til venstre).",
@@ -573,9 +566,6 @@ OC.L10N.register(
     "Enable text processing through LLMs" : "Aktiver tekstprosessering gjennom LLM-er",
     "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "Mail-appen kan behandle brukerdata ved hjelp av den konfigurerte store språkmodellen og gi assistansefunksjoner som trådsammendrag, smarte svar og hendelsesagendaer.",
     "Enable LLM processing" : "Aktiver LLM-prosessering",
-    "Enable classification by importance by default" : "Aktiver klassifisering etter viktighet som standard",
-    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "E-post-appen kan klassifisere innkommende e-post etter viktighet ved hjelp av maskinlæring. Denne funksjonen er aktivert som standard, men kan deaktiveres som standard her. Enkeltbrukere vil fortsatt kunne veksle mellom funksjonen for kontoene sine.",
-    "Enable classification of important mails by default" : "Aktiver klassifisering etter viktige e-poster som standard",
     "Anti Spam Service" : "Anti spam tjeneste",
     "You can set up an anti spam service email address here." : "Du kan sette opp en e-postadresse for antispamtjeneste her.",
     "Any email that is marked as spam will be sent to the anti spam service." : "Enhver e-post som er merket som spam vil bli sendt til anti spam-tjenesten.",
@@ -661,7 +651,6 @@ OC.L10N.register(
     "To add a mail account, please contact your administrator." : "For å legge til en e-postkonto, vennligst kontakt administratoren.",
     "All" : "Alle",
     "Drafts" : "Kladder",
-    "Favorites" : "Favoritter",
     "Priority inbox" : "Prioritert innboks",
     "All inboxes" : "Alle innbokser",
     "Inbox" : "Innboks",
@@ -693,29 +682,11 @@ OC.L10N.register(
     "The link leads to %s" : "Denne lenken leder til %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke vil besøke den siden, kan du gå tilbake til <a href=\"%s\">E-post</a>",
     "Continue to %s" : "Fortsett til %s",
-    "Search in the body of messages in priority Inbox" : "Søke i meldingsteksten i prioritert innboks",
-    "Put my text to the bottom of a reply instead of on top of it." : "Legg teksten min nederst i et svar i stedet for på toppen av det.",
-    "Use internal addresses" : "Bruk interne adresser",
-    "Accounts" : "Kontoer",
-    "Newest" : "Nyeste",
-    "Oldest" : "Eldst",
-    "Reply text position" : "Svartekstposisjon",
-    "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
-    "Register as application for mail links" : "Registrer som applikasjon for e-postlenker",
-    "Data collection consent" : "Samtykke til innsamling av data",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillat at appen samler inn data om interaksjonene dine. Basert på disse dataene vil appen tilpasse seg dine preferanser. Dataene vil kun bli lagret lokalt.",
-    "Trusted senders" : "Pålitelige avsendere",
-    "Internal addresses" : "Interne adresser",
-    "Manage S/MIME certificates" : "Administrer S/MIME-sertifikater",
-    "Contact or email address …" : "Kontakt eller e-post adresse ...",
-    "Subject …" : "Emne ...",
-    "Write message …" : "Skriv melding ...",
-    "Saving draft …" : "Lagrer kladd…",
-    "Loading messages …" : "Laster meldinger ...",
-    "Loading …" : "Laster...",
-    "Contact name …" : "Kontakt navn ...",
-    "Signature …" : "Signatur ...",
-    "Saving new tag name …" : "Lagrer nytt tagnavn …",
-    "Saving tag …" : "Lagrer tag …"
+    "Last 7 days" : "Siste 7 dager",
+    "From me" : "Fra meg",
+    "Could not save default classification setting" : "Kan ikke lagre standard klassifiseringsinnstilling",
+    "Enable classification by importance by default" : "Aktiver klassifisering etter viktighet som standard",
+    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "E-post-appen kan klassifisere innkommende e-post etter viktighet ved hjelp av maskinlæring. Denne funksjonen er aktivert som standard, men kan deaktiveres som standard her. Enkeltbrukere vil fortsatt kunne veksle mellom funksjonen for kontoene sine.",
+    "Enable classification of important mails by default" : "Aktiver klassifisering etter viktige e-poster som standard"
 },
 "nplurals=2; plural=(n != 1);");
