@@ -30,6 +30,7 @@ OC.L10N.register(
     "Email address" : "Adreça mail",
     "Cancel" : "Anullar",
     "General" : "Generals",
+    "Appearance" : "Aparéncia",
     "List" : "Tièra",
     "Privacy" : "Confidencialitat",
     "Security" : "Seguretat",
@@ -71,6 +72,7 @@ OC.L10N.register(
     "Move" : "Move",
     "Folder name" : "Nom del dorsièr",
     "_{total} message_::_{total} messages_" : ["{total} messatge","{total} messatges"],
+    "Loading …" : "Cargament …",
     "Delete folder" : "Suprimir dossièr",
     "Mark all as read" : "Marcar totes coma legits",
     "Rename" : "Tornar nommar",
