@@ -61,10 +61,9 @@ OC.L10N.register(
     "Sorting" : "Assentende",
     "Newest first" : "In antis is prus reghentes",
     "Oldest first" : "In antis is prus betzos",
-    "Register" : "Registra",
     "Shared with me" : "Cumpartzidos cun megus",
     "Security" : "Seguresa",
-    "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
+    "About" : "In contu de",
     "Compose new message" : "Iscrie messàgiu nou",
     "Newer message" : "Messàgiu prus reghente",
     "Older message" : "Messàgiu prus betzu",
@@ -75,7 +74,6 @@ OC.L10N.register(
     "Search" : "Chirca",
     "Send" : "Imbia",
     "Refresh" : "Agiorna",
-    "About" : "In contu de",
     "Ok" : "AB",
     "Message {id} could not be found" : "Su messàgiu {id} no s'est pòdidu agatare",
     "From" : "Dae",
@@ -146,7 +144,6 @@ OC.L10N.register(
     "individual" : "individuale",
     "domain" : "domìniu",
     "Remove" : "Boga",
-    "email" : "posta eletrònica",
     "Add internal address" : "Agiunghe indiritzu internu",
     "Itinerary for {type} is not supported yet" : "S'itineràriu pro {type} no est ancora suportadu",
     "Last hour" : "Ùrtima ora",
@@ -156,6 +153,7 @@ OC.L10N.register(
     "Choose target folder" : "Sèbera cartella de destinatzione",
     "No more submailboxes in here" : "Non b'at àteras suta-cartellas inoghe",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Is messàgios s'ant a marcare in manera automàtica comente importantes in sa base de is messàgios cun is chi as tènnidu interatziones o chi si sunt marcados comente importantes. Fortzis a su cumintzu as a dèpere cambiare a manu s'importàntzia pro ddu imparare a su sistema, ma at a megiorare in su tempus.",
+    "Favorites" : "Preferidos",
     "Important info" : "Informatzione importante",
     "Other" : "Àteru",
     "Could not send mdn" : "No at fatu a imbiare mdn",
@@ -229,7 +227,6 @@ OC.L10N.register(
     "Date" : "Data",
     "Tags" : "Etichetas",
     "Select tags" : "Seletziona etichetas",
-    "Last 7 days" : "Ùrtimas 7 dies",
     "Sieve Port" : "Porta Sieve",
     "Custom" : "Personaliza",
     "Sieve User" : "Utente Sieve",
@@ -257,6 +254,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} dae {depStation} a {arrStation}",
     "Train from {depStation} to {arrStation}" : "Trenu dae {depStation} a {arrStation}",
     "Train" : "Trenu",
+    "Deleted" : "Cantzelladu",
     "New filter" : "Filtru nou",
     "Help" : "Agiudu",
     "matches" : "currispondèntzias",
@@ -321,7 +319,6 @@ OC.L10N.register(
     "Connect your mail account" : "Connete·ti a su contu de posta tuo",
     "All" : "Totu",
     "Drafts" : "Brutacòpias",
-    "Favorites" : "Preferidos",
     "Priority inbox" : "Posta retzida cun prioridade",
     "All inboxes" : "Totu is casellas de posta retzida",
     "Inbox" : "Posta retzida",
@@ -345,21 +342,6 @@ OC.L10N.register(
     "Redirect" : "Torra a deretare",
     "The link leads to %s" : "Su ligòngiu deretat a %s",
     "Continue to %s" : "Sighi in %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Pone su testu miu a su fundu de una resposta imbetzes che a pitzus.",
-    "Accounts" : "Accounts",
-    "Newest" : "Prus nou",
-    "Use Gravatar and favicon avatars" : "Imprea Gravatar e avatar favicon",
-    "Register as application for mail links" : "Registra comente aplicatzione pro is ligòngios de posta",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permite a s'aplicatzione de regòllere datos subra is interatziones tuas. In sa base de custos datos, s'aplicatziones s'at a adatare a is preferèntzias tuas. Is datos ant a èssere archiviados in manera locale isceti. ",
-    "Trusted senders" : "Imbiantes afidàbiles",
-    "Contact or email address …" : "Cuntatu o indiritzu de posta ...",
-    "Subject …" : "Ogetu",
-    "Write message …" : "Iscrie messàgiu ...",
-    "Saving draft …" : "Sarvende sa brutacòpia ...",
-    "Loading …" : "Carrrighende …",
-    "Contact name …" : "Nùmene de su cuntatu ...",
-    "Signature …" : "Firma ...",
-    "Saving new tag name …" : "Sarvende nùmene de eticheta nou...",
-    "Saving tag …" : "Sarvende s'eticheta ..."
+    "Last 7 days" : "Ùrtimas 7 dies"
 },
 "nplurals=2; plural=(n != 1);");
