@@ -93,12 +93,11 @@ OC.L10N.register(
     "Sorting" : "Razvrščanje",
     "Newest first" : "najprej najnovejše",
     "Oldest first" : "najprej najstarejše",
-    "Gravatar settings" : "Nastavitve Gravatar",
-    "Register" : "Vpis računa",
     "Shared with me" : "V souporabi z mano",
+    "Privacy" : "Zasebnost",
     "Security" : "Varnostna opozorila",
     "Manage certificates" : "Upravljanje s potrdili",
-    "Keyboard shortcuts" : "Tipkovne bližnjice",
+    "About" : "O meni",
     "Compose new message" : "Novo sporočilo",
     "Newer message" : "Novejše sporočilo",
     "Older message" : "Starejše sporočilo",
@@ -109,7 +108,6 @@ OC.L10N.register(
     "Search" : "Iskanje",
     "Send" : "Pošlji",
     "Refresh" : "Osveži",
-    "About" : "O meni",
     "Ok" : "Sprejemljivo",
     "No certificate" : "Ni potrdil",
     "Certificate updated" : "Potrdilo je posodobljeno",
@@ -239,7 +237,6 @@ OC.L10N.register(
     "individual" : "posamično",
     "domain" : "domena",
     "Remove" : "Odstrani",
-    "email" : "elektronska pošta",
     "Itinerary for {type} is not supported yet" : "{type} – vrsta prevoza še ni podprta",
     "Last hour" : "Zadnja ura",
     "Today" : "Danes",
@@ -248,6 +245,7 @@ OC.L10N.register(
     "Choose target folder" : "Izbor ciljne mape",
     "No more submailboxes in here" : "V tem predalu ni drugih predalov",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Sporočila bodo samodejno označena kot pomembna na podlagi do sedaj označenih takih sporočil. V začetku bo verjetno treba kakšno označiti še ročno, a se bo sistem s časom izboljševal.",
+    "Favorites" : "Priljubljene",
     "Important info" : "Pomembno",
     "Other" : "Drugo",
     "Could not send mdn" : "Sporočila ni mogoče poslati",
@@ -305,7 +303,6 @@ OC.L10N.register(
     "Delete folder {name}" : "Izbriši mapo {name}",
     "An error occurred, unable to rename the mailbox." : "Prišlo je do napake; poštnega predala ni mogoče preimenovati.",
     "Mark all as read" : "Označi vse kot prebrano",
-    "Mark all messages of this folder as read" : "Označi vsa sporočila v tej mapi kot prebrana",
     "Add subfolder" : "Dodaj podmapo",
     "Rename" : "Preimenuj",
     "Move folder" : "Premakni mapo",
@@ -359,7 +356,6 @@ OC.L10N.register(
     "Select tags" : "Izbor oznak",
     "Marked as" : "Označeno kot",
     "Has attachments" : "Vsebuje prilogo",
-    "Last 7 days" : "Zadnjih 7 dni",
     "Sieve Port" : "Vrata Sieve",
     "Custom" : "Po meri",
     "Sieve User" : "Uporabnik Sieve",
@@ -417,6 +413,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} v {arrStation}",
     "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} v {arrStation}",
     "Train" : "Vlak",
+    "Deleted" : "Izbrisano",
     "Recipient" : "Prejemnik",
     "Delete filter" : "Izbriši filter",
     "Help" : "Pomoč",
@@ -500,7 +497,6 @@ OC.L10N.register(
     "Connect your mail account" : "Povežite svoj elektronski račun",
     "All" : "Vse",
     "Drafts" : "Osnutki",
-    "Favorites" : "Priljubljene",
     "Priority inbox" : "Prednostni dohodni predal",
     "All inboxes" : "Vsi predali",
     "Inbox" : "Prejeto",
@@ -529,25 +525,7 @@ OC.L10N.register(
     "Redirect" : "Preusmeri",
     "The link leads to %s" : "Povezava vodi do %s",
     "Continue to %s" : "Nadaljuj na %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Dodaj besedilo odgovora pod izvorno sporočilo in ne nad.",
-    "Accounts" : "Računi",
-    "Newest" : "Najnovejše",
-    "Oldest" : "Najstarejše",
-    "Use Gravatar and favicon avatars" : "Uporabi podobe Gravatar in Favicon",
-    "Register as application for mail links" : "Nastavi kot program za odpiranje povezav na poštne elektronske naslove",
-    "Data collection consent" : "Strinjanje z zbiranjem podatkov",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Program lahko zbira podatke o vaših pogostih dejanjih in na podlagi teh podatkov prilagaja delovanje vašemu načinu uporabe. Podatki se shranjujejo le krajevno.",
-    "Trusted senders" : "Zaupanja vredni pošiljatelji",
-    "Manage S/MIME certificates" : "Upravljanje s potrdili S/MIME",
-    "Contact or email address …" : "Stik ali elektronski naslov ...",
-    "Subject …" : "Zadeva ...",
-    "Write message …" : "Besedilo sporočila ...",
-    "Saving draft …" : "Poteka shranjevanje osnutka ...",
-    "Loading messages …" : "Poteka nalaganje sporočil ...",
-    "Loading …" : "Poteka nalaganje …",
-    "Contact name …" : "Ime stika …",
-    "Signature …" : "Podpis ...",
-    "Saving new tag name …" : "Poteka shranjevanje imena oznake ...",
-    "Saving tag …" : "Poteka shranjevanje ozake ..."
+    "Mark all messages of this folder as read" : "Označi vsa sporočila v tej mapi kot prebrana",
+    "Last 7 days" : "Zadnjih 7 dni"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
