@@ -18,6 +18,7 @@ OC.L10N.register(
     "Signature" : "Saini",
     "Filters" : "Filters",
     "Go back" : "Rudi nyuma",
+    "Change name" : "Change name",
     "Email address" : "Anwani ya barua pepe",
     "Cancel" : "Cancel",
     "General" : "Kuu",
@@ -27,16 +28,15 @@ OC.L10N.register(
     "Sorting" : "Sorting",
     "Newest first" : "Mpya kwanza",
     "Oldest first" : "Ya zamani kwanza",
-    "Register" : "Sajiri",
     "Shared with me" : "Shared with me",
+    "Privacy" : "Faragha",
     "Security" : "Ulinzi",
-    "Keyboard shortcuts" : "Mikato ya keyboard",
+    "About" : "Kuhusu",
     "Archive" : "Weka kumbukumbu",
     "Delete" : "Futa",
     "Search" : "Tafuta",
     "Send" : "Tuma",
     "Refresh" : "Refresh",
-    "About" : "Kuhusu",
     "Ok" : "Sawa",
     "From" : "Tangu/ kutoka",
     "Select account" : "Chagua akaunti",
@@ -61,6 +61,7 @@ OC.L10N.register(
     "Favorite" : "Kipendwa",
     "Unread" : "Unread",
     "Read" : "Soma",
+    "Move thread" : "Move thread",
     "Delete message" : "Delete message",
     "More actions" : "Vitendo zaidi",
     "Back" : "Rudi",
@@ -85,6 +86,7 @@ OC.L10N.register(
     "Last week" : "Wiki iliyopita",
     "Last month" : "Mwezi uliopita",
     "Choose target folder" : "Chagua kasha lililolengwa",
+    "Favorites" : "Vipendwa",
     "Other" : "Mengine",
     "Forward" : "Mbele",
     "Translate" : "Tafsiri",
@@ -103,6 +105,7 @@ OC.L10N.register(
     "Move folder" : "Move folder",
     "Clear cache" : "Clear cache",
     "Subscribed" : "Iliyojisajili",
+    "Delete all messages" : "Futa jumbe zote ",
     "New message" : "Ujumbe mpya",
     "Edit message" : "Hariri ujumbe",
     "Draft" : "Draft",
@@ -120,7 +123,6 @@ OC.L10N.register(
     "Date" : "Tarehe",
     "Tags" : "Maoni",
     "Select tags" : "Chagua ukumbusho",
-    "Last 7 days" : "Siku 7 zilizopita",
     "Custom" : "Mteja",
     "Add tag" : "Add tag",
     "Not found" : "Haipatikani",
@@ -137,6 +139,7 @@ OC.L10N.register(
     "Copy translated text" : "Nakili maandishi yaliyotafsiriwa",
     "Untitled event" : "Tukio lisilotajwa",
     "(organizer)" : "(Mratibu)",
+    "Deleted" : "Vilivyofutwa",
     "Help" : "Msaada",
     "contains" : "contains",
     "matches" : "matches",
@@ -158,14 +161,12 @@ OC.L10N.register(
     "Shares" : "Shiriki",
     "Account connected" : "Akaunti imeunganishwa",
     "All" : "Zote",
-    "Favorites" : "Vipendwa",
     "Error while sharing file" : "Hitilafu wakati wa kushirikisha faili",
     "Nextcloud Mail" : "Nextcloud Mail",
     "Discard changes" : "Discard changes",
     "Message sent" : "Ujumbe umetumwa",
     "Redirect" : "Elekeza upya",
     "Continue to %s" : "Endelea katika %s",
-    "Accounts" : "Akaunti",
-    "Loading …" : "Inapakia"
+    "Last 7 days" : "Siku 7 zilizopita"
 },
 "nplurals=2; plural=(n != 1);");
