@@ -15,15 +15,13 @@ OC.L10N.register(
     "General" : "Umumiy",
     "Appearance" : "Tashqi ko'rinish",
     "List" : "Ro`yxat",
-    "Register" : "Roʻyxatdan oʻtish",
     "Security" : "Xavfsizlik",
-    "Keyboard shortcuts" : "Klaviatura yorliqlari",
+    "About" : "About",
     "Archive" : "Arxiv",
     "Delete" : "O'chirish",
     "Search" : "Qidirish",
     "Send" : "Send",
     "Refresh" : "Refresh",
-    "About" : "About",
     "Ok" : "Yaxshi",
     "From" : "Dan",
     "To" : "Gacha",
@@ -46,11 +44,11 @@ OC.L10N.register(
     "Decline" : "Rad etish",
     "More options" : "Boshqa variantlar",
     "Remove" : "O'chirish",
-    "email" : "email",
     "Today" : "Bugun",
     "Yesterday" : "Kecha",
     "Last week" : "O`tgan yil",
     "Last month" : "Oxirgi oy",
+    "Favorites" : "Favorites",
     "Other" : "Boshqa",
     "Translate" : "Tarjima",
     "Move" : "Move",
@@ -66,12 +64,12 @@ OC.L10N.register(
     "Close" : "Yopish",
     "Date" : "Sana",
     "Tags" : "Tags",
-    "Last 7 days" : "Oxirgi 7 kun",
     "Custom" : "Boshqa",
     "Add tag" : "Teg qo'shing",
     "Not found" : "Topilmadi",
     "Untitled event" : "Nomsiz tadbir",
     "(organizer)" : "(tashkilotchi)",
+    "Deleted" : "O`chirilgan",
     "Help" : "Yordam",
     "contains" : "o'z ichiga oladi",
     "Actions" : "Faolliklar",
@@ -83,10 +81,8 @@ OC.L10N.register(
     "Shared" : "Ulashilgan",
     "Account connected" : "Akkaunt ulangan",
     "All" : "All",
-    "Favorites" : "Favorites",
     "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
     "Continue to %s" : " %sni davom eting",
-    "Accounts" : "Akkaunt",
-    "Loading …" : "Yuklanmoqda…"
+    "Last 7 days" : "Oxirgi 7 kun"
 },
 "nplurals=1; plural=0;");
