@@ -53,9 +53,9 @@ OC.L10N.register(
     "List" : "Danh sách",
     "Newest first" : "Mới nhất trước",
     "Oldest first" : "Cũ nhất trước",
-    "Register" : "Đăng ký",
+    "Privacy" : "Bảo mật",
     "Security" : "Bảo mật",
-    "Keyboard shortcuts" : "Phím tắt",
+    "About" : "Giới thiệu",
     "Compose new message" : "Soạn tin nhăn mơi",
     "Newer message" : "Tin nhắn mới hơn",
     "Older message" : "Tin nhắn cũ hơn",
@@ -66,7 +66,6 @@ OC.L10N.register(
     "Search" : "Tìm",
     "Send" : "Gởi",
     "Refresh" : "Làm mới",
-    "About" : "Giới thiệu",
     "Ok" : "Đồng ý",
     "Message {id} could not be found" : "Không tìm thấy tin nhắn {id}",
     "From" : "Từ",
@@ -125,7 +124,6 @@ OC.L10N.register(
     "individual" : "Cá nhận",
     "domain" : "Miền",
     "Remove" : "Xóa",
-    "email" : "Thư điện tử",
     "Itinerary for {type} is not supported yet" : "Hành trình cho {type} chưa được hỗ trợ",
     "Today" : "Hôm nay",
     "Yesterday" : "Hôm qua",
@@ -134,6 +132,7 @@ OC.L10N.register(
     "Choose target folder" : "Chọn thư mục đích",
     "No more submailboxes in here" : "Không còn hộp thư con nào ở đây",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Tin nhắn sẽ tự động được đánh dấu là quan trọng dựa trên những tin nhắn bạn đã tương tác hoặc được đánh dấu là quan trọng. Lúc đầu, bạn có thể phải thay đổi thủ công tầm quan trọng để dạy hệ thống, nhưng nó sẽ cải thiện theo thời gian.",
+    "Favorites" : "Ưa thích",
     "Important info" : "Thông tin quan trọng",
     "Other" : "Khác",
     "Could not send mdn" : "Không thể gửi mdn",
@@ -195,7 +194,6 @@ OC.L10N.register(
     "Date" : "Date",
     "Tags" : "Nhãn",
     "Select tags" : "Chọn một thẻ",
-    "Last 7 days" : "7 ngày trước",
     "Sieve Port" : "Cổng Sieve",
     "Custom" : "Tùy chỉnh",
     "Sieve User" : "Người dùng Sieve",
@@ -221,6 +219,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} từ {depStation} đến {arrStation}",
     "Train from {depStation} to {arrStation}" : "Đi tàu từ {depStation} đến {arrStation}",
     "Train" : "Tàu hỏa",
+    "Deleted" : "Đã xoá",
     "Recipient" : "Người nhận",
     "Delete filter" : "Xóa bộ lọc ",
     "Help" : "Trợ giúp",
@@ -254,7 +253,6 @@ OC.L10N.register(
     "Connect your mail account" : "Kết nối tài khoản thư của bạn",
     "All" : "Tất cả",
     "Drafts" : "Bản nháp",
-    "Favorites" : "Ưa thích",
     "Priority inbox" : "Hộp thư ưu tiên",
     "All inboxes" : "Tất cả hộp thư đến",
     "Inbox" : "Hộp thư đến",
@@ -277,18 +275,6 @@ OC.L10N.register(
     "Redirect" : "Chuyển hướng",
     "The link leads to %s" : "Liên kết dẫn đến %s",
     "Continue to %s" : "Tiếp tục %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Đặt văn bản ở cuối thư trả lời thay vì ở đầu thư.",
-    "Accounts" : "Tài khoản",
-    "Use Gravatar and favicon avatars" : "Sử dụng hình đại diện Gravatar và favicon",
-    "Register as application for mail links" : "Đăng ký làm ứng dụng cho các liên kết gửi thư",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Cho phép ứng dụng thu thập dữ liệu về các tương tác của bạn. Dựa trên dữ liệu này, ứng dụng sẽ điều chỉnh theo sở thích của bạn. Dữ liệu sẽ chỉ được lưu trữ trên máy của bạn.",
-    "Trusted senders" : "Người gửi đáng tin cậy",
-    "Contact or email address …" : "Địa chỉ liên hệ hoặc thư điện tử …",
-    "Subject …" : "Chủ đề …",
-    "Write message …" : "Viết tin nhắn …",
-    "Saving draft …" : "Đang lưu bản nháp …",
-    "Loading …" : "Đang tải...",
-    "Contact name …" : "Tên người liên hệ …",
-    "Signature …" : "Chữ ký …"
+    "Last 7 days" : "7 ngày trước"
 },
 "nplurals=1; plural=0;");
