@@ -17,8 +17,6 @@ class PhishingDetectionList implements JsonSerializable {
 	/** @var PhishingDetectionResult[] */
 	private array $checks;
 
-	private bool $warning = false;
-
 	/**
 	 * @param PhishingDetectionResult[] $checks
 	 */
@@ -26,11 +24,11 @@ class PhishingDetectionList implements JsonSerializable {
 		$this->checks = $checks;
 	}
 
-	public function addCheck(PhishingDetectionResult $check) {
+	public function addCheck(PhishingDetectionResult $check): void {
 		$this->checks[] = $check;
 	}
 
-	private function isWarning() {
+	private function isWarning(): bool {
 		foreach ($this->checks as $check) {
 			if (in_array($check->getType(), [PhishingDetectionResult::DATE_CHECK, PhishingDetectionResult::LINK_CHECK, PhishingDetectionResult::CUSTOM_EMAIL_CHECK, PhishingDetectionResult::CONTACTS_CHECK]) && $check->isPhishing()) {
 				return true;
@@ -39,11 +37,10 @@ class PhishingDetectionList implements JsonSerializable {
 		return false;
 	}
 
+	#[\Override]
 	#[ReturnTypeWillChange]
 	public function jsonSerialize() {
-		$result = array_map(static function (PhishingDetectionResult $check) {
-			return $check->jsonSerialize();
-		}, $this->checks);
+		$result = array_map(static fn (PhishingDetectionResult $check) => $check->jsonSerialize(), $this->checks);
 		return [
 			'checks' => $result,
 			'warning' => $this->isWarning(),
