@@ -15,7 +15,7 @@ use ReturnTypeWillChange;
 /**
  * @psalm-immutable
  */
-class Configuration implements JsonSerializable {
+final class Configuration implements JsonSerializable {
 	private ?ServerConfiguration $imapConfig;
 	private ?ServerConfiguration $smtpConfig;
 
@@ -25,6 +25,7 @@ class Configuration implements JsonSerializable {
 		$this->smtpConfig = $smtpConfig;
 	}
 
+	#[\Override]
 	#[ReturnTypeWillChange]
 	public function jsonSerialize() {
 		return [
