@@ -35,13 +35,24 @@ class QuickActionsService {
 		private ActionStepMapper $actionStepMapper,
 	) {
 	}
-
 	/**
 	 * @param string $userId
 	 * @return Actions[]
 	 */
 	public function findAll(string $userId): array {
-		return $this->actionsMapper->findAll($userId);
+		$actions = $this->actionsMapper->findAll($userId);
+		$actionIds = array_map(fn (Actions $action) => $action->getId(), $actions);
+		$actionSteps = $this->actionStepMapper->findStepsByActionIds($actionIds, $userId);
+		return array_map(function (Actions $action) use ($actionSteps) {
+			$steps = array_values(array_filter($actionSteps, function (ActionStep $step) use ($action) {
+				return $step->getActionId() === $action->getId();
+			}));
+			$action->setActionSteps($steps);
+			if (!empty($steps)) {
+				$action->setIcon($steps[0]->getName());
+			}
+			return $action;
+		}, $actions);
 	}
 
 	/**
@@ -74,14 +85,6 @@ class QuickActionsService {
 		$this->actionsMapper->delete($action);
 	}
 
-	/**
-	 * @param string $userId
-	 * @return ActionStep[]
-	 */
-	public function findAllActionSteps(int $actionId, string $userId): array {
-		return $this->actionStepMapper->findAllStepsForOneAction($actionId, $userId);
-	}
-
 	/**
 	 * @throws DoesNotExistException
 	 */
