@@ -343,9 +343,7 @@ class ImapToDbSynchronizer {
 		}
 
 		foreach (array_chunk($imapMessages['messages'], 500) as $chunk) {
-			$messages = array_map(static function (IMAPMessage $imapMessage) use ($mailbox, $account) {
-				return $imapMessage->toDbMessage($mailbox->getId(), $account->getMailAccount());
-			}, $chunk);
+			$messages = array_map(static fn (IMAPMessage $imapMessage) => $imapMessage->toDbMessage($mailbox->getId(), $account->getMailAccount()), $chunk);
 			$this->dbMapper->insertBulk($account, ...$messages);
 			$perf->step(sprintf('persist %d messages in database', count($chunk)));
 			// Free the memory
@@ -420,9 +418,7 @@ class ImapToDbSynchronizer {
 				// Filter out anything that is already in the DB. Ideally this never happens, but if there is an error
 				// during a consecutive chunk INSERT, the sync token won't be updated. In that case the same message(s)
 				// will be seen as *new* and therefore cause conflicts.
-				$newMessages = array_filter($response->getNewMessages(), static function (IMAPMessage $imapMessage) use ($highestKnownUid) {
-					return $imapMessage->getUid() > $highestKnownUid;
-				});
+				$newMessages = array_filter($response->getNewMessages(), static fn (IMAPMessage $imapMessage) => $imapMessage->getUid() > $highestKnownUid);
 			}
 
 			$importantTag = null;
@@ -435,9 +431,7 @@ class ImapToDbSynchronizer {
 			}
 
 			foreach (array_chunk($newMessages, 500) as $chunk) {
-				$dbMessages = array_map(static function (IMAPMessage $imapMessage) use ($mailbox, $account) {
-					return $imapMessage->toDbMessage($mailbox->getId(), $account->getMailAccount());
-				}, $chunk);
+				$dbMessages = array_map(static fn (IMAPMessage $imapMessage) => $imapMessage->toDbMessage($mailbox->getId(), $account->getMailAccount()), $chunk);
 
 				$this->dbMapper->insertBulk($account, ...$dbMessages);
 
@@ -479,9 +473,7 @@ class ImapToDbSynchronizer {
 			$permflagsEnabled = $this->mailManager->isPermflagsEnabled($client, $account, $mailbox->getName());
 
 			foreach (array_chunk($response->getChangedMessages(), 500) as $chunk) {
-				$this->dbMapper->updateBulk($account, $permflagsEnabled, ...array_map(static function (IMAPMessage $imapMessage) use ($mailbox, $account) {
-					return $imapMessage->toDbMessage($mailbox->getId(), $account->getMailAccount());
-				}, $chunk));
+				$this->dbMapper->updateBulk($account, $permflagsEnabled, ...array_map(static fn (IMAPMessage $imapMessage) => $imapMessage->toDbMessage($mailbox->getId(), $account->getMailAccount()), $chunk));
 			}
 			$perf->step('persist changed messages');
 
